@@ -9,15 +9,8 @@ The example uses <packages> to <do something> and <other package> to <do other
 thing>. Include links to referenced packages like this: `sunpy.io.fits` to
 show the sunpy.io.fits or like this `~sunpy.io.fits`to show just 'fits'
 """
-###########################################################################
-# If you have multiple plots in your example, Sphinx will use the first
-# plot for the thumbnail by default. You can set which plot is used as the
-# thumbnail by adding the following comment to your file.
-# ``#sphinx_gallery_thumbnail_number = X```
-# where ``X`` is the figure number you want (from 1).
-
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
 ##############################################################################
 # This code block is executed, although it produces no output. Lines starting
@@ -68,7 +61,6 @@ def dummy():
     """
     Dummy function to make sure docstrings don't get rendered as text.
     """
-    pass
 
 # Code comments not preceded by the hash splitter are left in code blocks.
 
@@ -87,3 +79,11 @@ print('Some output from Python')
 # code directly will see the plots; this is not necessary for creating the docs
 
 plt.show()
+
+###########################################################################
+# If you have multiple plots in your example, Sphinx will use the first
+# plot for the thumbnail by default. You can set which plot is used as the
+# thumbnail by adding the following comment to your file.
+# ``#sphinx_gallery_thumbnail_number = X```
+# where ``X`` is the figure number you want (from 1).
+# We suggest putting this at the end.
