@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 ==============
 Cropping a Map
@@ -6,12 +5,13 @@ Cropping a Map
 
 How to crop a map by using submap.
 """
+import matplotlib.pyplot as plt
+
 import astropy.units as u
 from astropy.coordinates import SkyCoord
 
-import sunpy.map
 import sunpy.data.sample
-import matplotlib.pyplot as plt
+import sunpy.map
 
 ###############################################################################
 # We start with the sample data
@@ -22,7 +22,7 @@ swap_map = sunpy.map.Map(sunpy.data.sample.SWAP_LEVEL1_IMAGE)
 # left as SkyCoord objects.
 top_right = SkyCoord(0 * u.arcsec, -200 * u.arcsec, frame=swap_map.coordinate_frame)
 bottom_left = SkyCoord(-900 * u.arcsec, -900 * u.arcsec, frame=swap_map.coordinate_frame)
-swap_submap = swap_map.submap(bottom_left, top_right)
+swap_submap = swap_map.submap(bottom_left, top_right=top_right)
 
 ###############################################################################
 # Let's plot the results
