@@ -5,8 +5,9 @@ Making a power spectrum from a TimeSeries
 
 How to estimate the power spectrum of a TimeSeries.
 """
-import matplotlib.pyplot as plt 
+import matplotlib.pyplot as plt
 from scipy import signal
+
 import astropy.units as u
 
 import sunpy.timeseries
@@ -19,14 +20,14 @@ from sunpy.data.sample import RHESSI_TIMESERIES
 ts = sunpy.timeseries.TimeSeries(RHESSI_TIMESERIES)
 
 ###############################################################################
-# We now use SciPy's `~scipy.signal.periodogram` to estimate the 
+# We now use SciPy's `~scipy.signal.periodogram` to estimate the
 # power spectra of the first column of the Timeseries. The first column contains
 # X-Ray emmisions in the range of 3-6 keV. An alternative version is Astropy's
 # `~astropy.stats.LombScargle` periodogram.
 
 x_ray = ts.columns[0]
 # The suitable value for fs would be 0.25 Hz as the time step is 4 s.
-freq, spectra = signal.periodogram(ts.data[x_ray], fs=0.25)
+freq, spectra = signal.periodogram(ts.quantity(x_ray), fs=0.25)
 
 ###############################################################################
 # Let's plot the results
