@@ -15,16 +15,11 @@ from sunpy.tests.runner import SunPyTestRunner
 from sunpy.util import system_info
 from sunpy.util.config import load_config, print_config
 from sunpy.util.logger import _init_log
+from .version import version as __version__
 
 # Enforce Python version check during package import.
 __minimum_python_version__ = "3.6"
 
-try:
-    from .version import __version__
-except ImportError:
-    print("version.py not found, please reinstall sunpy.")
-    __version__ = "unknown"
-
 
 class UnsupportedPythonError(Exception):
     pass
@@ -38,10 +33,12 @@ if sys.version_info < tuple(int(val) for val in __minimum_python_version__.split
 
 def _get_bibtex():
     import textwrap
+
     # Set the bibtex entry to the article referenced in CITATION.rst
     citation_file = os.path.join(os.path.dirname(__file__), 'CITATION.rst')
 
-    with open(citation_file, 'r') as citation:
+    # Explicitly specify UTF-8 encoding in case the system's default encoding is problematic
+    with open(citation_file, 'r', encoding='utf-8') as citation:
         # Extract the first bibtex block:
         ref = citation.read().partition(".. code:: bibtex\n\n")[2]
         lines = ref.split("\n")
@@ -53,16 +50,13 @@ def _get_bibtex():
 
 __citation__ = __bibtex__ = _get_bibtex()
 
-
 self_test = SunPyTestRunner.make_test_runner_in(os.path.dirname(__file__))
 
 # Load user configuration
 config = load_config()
 
-
 # Use the root logger as a dummy log before initializing Astropy's logger
 log = logging.getLogger()
-
 log = _init_log(config=config)
 
-__all__ = ['config', 'self_test', 'system_info']
+__all__ = ['config', 'self_test', 'system_info', 'print_config']
