@@ -20,6 +20,7 @@ from astropy.time import Time
 from sunpy.sun.constants import radius as _RSUN
 from sunpy.time.time import _variables_for_parse_time_docstring
 from sunpy.util.decorators import add_common_docstring, deprecated
+from sunpy.util.exceptions import SunpyUserWarning
 from .frameattributes import ObserverCoordinateAttribute, TimeFrameAttributeSunPy
 
 _J2000 = Time('J2000.0', scale='tt')
@@ -113,7 +114,7 @@ class SunPyBaseCoordinateFrame(BaseCoordinateFrame):
 
         super().__init__(*args, **kwargs)
 
-        # If obstime is specified, treat the default observer (Earth) as explicitly set
+        # If obstime is specified, treat the default observer (None) as explicitly set
         if self.obstime is not None and self.is_frame_attr_default('observer'):
             self._attr_names_with_defaults.remove('observer')
 
@@ -175,10 +176,11 @@ class BaseHeliographic(SunPyBaseCoordinateFrame):
     }
 
     def __init__(self, *args, **kwargs):
-        kwargs.get('representation_type', None)
-
         super().__init__(*args, **kwargs)
 
+        self._make_3d()
+
+    def _make_3d(self):
         # Make 3D if specified as 2D
         if (self._data is not None and self._data.norm().unit is u.one
                 and u.allclose(self._data.norm(), 1*u.one)):
@@ -481,6 +483,16 @@ class Helioprojective(SunPyBaseCoordinateFrame):
         rep = self.represent_as(UnitSphericalRepresentation)
         lat, lon = rep.lat, rep.lon
         alpha = np.arccos(np.cos(lat) * np.cos(lon)).to(lat.unit)
+
+        # Check for the use of floats with lower precision than the native Python float
+        if not set([lon.dtype.type, lat.dtype.type]).issubset([float, np.float64, np.longdouble]):
+            raise SunpyUserWarning("The Helioprojective component values appear to be lower "
+                                   "precision than the native Python float: "
+                                   f"Tx is {lon.dtype.name}, and Ty is {lat.dtype.name}. "
+                                   "To minimize precision loss, you may want to cast the values to "
+                                   "`float` or `numpy.float64` via the NumPy method `.astype()`.")
+
+        # Calculate the distance to the surface of the Sun using the law of cosines
         c = self.observer.radius**2 - self.rsun**2
         b = -2 * self.observer.radius * np.cos(alpha)
         # Ingore sqrt of NaNs
