@@ -4,7 +4,6 @@ Sun-specific coordinate calculations
 import numpy as np
 
 import astropy.units as u
-from astropy import _erfa as erfa
 from astropy.constants import c as speed_of_light
 from astropy.coordinates import (
     ITRS,
@@ -20,6 +19,8 @@ from astropy.coordinates import (
 )
 from astropy.coordinates.builtin_frames.utils import get_jd12
 from astropy.coordinates.representation import CartesianRepresentation, SphericalRepresentation
+# Import erfa via astropy to make sure we are using the same ERFA library as Astropy
+from astropy.coordinates.sky_coordinate import erfa
 from astropy.time import Time
 
 from sunpy import log
@@ -50,12 +51,21 @@ def angular_radius(t='now'):
     """
     Return the angular radius of the Sun as viewed from Earth.
 
+    The tangent vector from the Earth to the edge of the Sun forms a
+    right-angle triangle with the radius of the Sun as the far side and the
+    Sun-Earth distance as the hypotenuse.  Thus, the sine of the angular
+    radius of the Sun is ratio of these two distances.
+
     Parameters
     ----------
     t : {parse_time_types}
         Time to use in a parse-time-compatible format
     """
-    solar_semidiameter_rad = np.arcsin(constants.radius / earth_distance(t))
+    return _angular_radius(constants.radius, earth_distance(t))
+
+
+def _angular_radius(sol_radius, distance):
+    solar_semidiameter_rad = np.arcsin(sol_radius / distance)
     return Angle(solar_semidiameter_rad.to(u.arcsec))
 
 
@@ -454,7 +464,6 @@ def B0(time='now'):
         * The heliographic latitude of Earth
         * The tilt of the solar North rotational axis toward Earth
 
-
     Parameters
     ----------
     time : {parse_time_types}
