@@ -1,16 +1,15 @@
-# -*- coding: utf-8 -*-
 
 import pytest
 
 import astropy.units as u
-from astropy.time import Time
+from astropy.coordinates import ICRS, HeliocentricMeanEcliptic, get_body_barycentric
 from astropy.tests.helper import assert_quantity_allclose
-from astropy.coordinates import ICRS, get_body_barycentric
+from astropy.time import Time
 
+from sunpy.coordinates import frames, get_earth
 from sunpy.time import parse_time
-from ..frames import Helioprojective, HeliographicStonyhurst
-from ..frameattributes import TimeFrameAttributeSunPy, ObserverCoordinateAttribute
-from sunpy.coordinates import get_earth, frames
+from ..frameattributes import ObserverCoordinateAttribute, TimeFrameAttributeSunPy
+from ..frames import HeliocentricInertial, HeliographicStonyhurst, Helioprojective
 
 
 @pytest.fixture
@@ -18,6 +17,11 @@ def attr():
     return TimeFrameAttributeSunPy()
 
 
+@pytest.fixture
+def oca():
+    return ObserverCoordinateAttribute(HeliographicStonyhurst)
+
+
 def test_now(attr):
     """ We can't actually test the value independantly """
     result, converted = attr.convert_input('now')
@@ -80,10 +84,7 @@ def test_on_frame_error2():
 # ObserverCoordinateAttribute
 
 
-def test_string_coord():
-
-    oca = ObserverCoordinateAttribute(HeliographicStonyhurst)
-
+def test_string_coord(oca):
     obstime = "2011-01-01"
     coord = oca._convert_string_to_coord("earth", obstime)
 
@@ -92,11 +93,29 @@ def test_string_coord():
     assert coord.obstime == parse_time(obstime)
 
 
+def test_observer_not_hgs_sunpy(oca):
+    observer = HeliocentricInertial(0*u.deg, 0*u.deg, 1*u.AU, obstime='2001-01-01')
+    result, converted = oca.convert_input(observer)
+
+    assert isinstance(result, HeliographicStonyhurst)
+    assert result.obstime == observer.obstime
+    assert converted
+
+
+def test_observer_not_hgs_astropy(oca):
+    observer = HeliocentricMeanEcliptic(0*u.deg, 0*u.deg, 1*u.AU, obstime='2001-01-01')
+    result, converted = oca.convert_input(observer)
+
+    assert isinstance(result, HeliographicStonyhurst)
+    assert result.obstime == observer.obstime
+    assert converted
+
+
 def test_coord_get():
 
     # Test default (instance=None)
     obs = Helioprojective.observer
-    assert obs == "earth"
+    assert obs is None
 
     # Test get
     obstime = "2013-04-01"
@@ -113,7 +132,7 @@ def test_coord_get():
 
     # Test get
     obstime = "2013-04-01"
-    obs = Helioprojective(obstime=obstime).observer
+    obs = Helioprojective(observer="earth", obstime=obstime).observer
     earth = get_earth(obstime)
     assert isinstance(obs, HeliographicStonyhurst)
     assert_quantity_allclose(obs.lon, earth.lon)
@@ -138,7 +157,7 @@ def test_coord_get():
 
 def test_default_hcc_observer():
     h = frames.Heliocentric()
-    assert h.observer == "earth"
+    assert h.observer is None
 
     h = frames.Heliocentric(observer="mars")
     assert h.observer == "mars"
@@ -148,8 +167,7 @@ def test_obstime_hack():
     """
     Test that the obstime can be updated in place, this is used in the transform pipeline.
     """
-    h = frames.Heliocentric()
-    assert h.observer == "earth"
+    h = frames.Heliocentric(observer="earth")
 
     obstime = "2011-01-01"
     h._obstime = obstime
@@ -162,23 +180,3 @@ def test_obstime_hack():
     assert_quantity_allclose(obs.lon, earth.lon)
     assert_quantity_allclose(obs.lat, earth.lat)
     assert_quantity_allclose(obs.radius, earth.radius)
-
-
-"""
-These two tests are to make sure that during the transformation stack the value
-of observer is correctly calculated.
-"""
-
-
-def test_default_observer_transform_hcc():
-    center = frames.HeliographicStonyhurst(0 * u.deg, 0 * u.deg, obstime="2017-07-11 15:00")
-    hpc = center.transform_to(frames.Heliocentric(obstime="2017-07-11 15:00"))
-
-    assert_quantity_allclose(hpc.y, -48484.509203 * u.km)
-
-
-def test_default_observer_transform_hpc():
-    center = frames.HeliographicStonyhurst(0 * u.deg, 0 * u.deg, obstime="2017-07-11 15:00")
-    hpc = center.transform_to(frames.Helioprojective(obstime="2017-07-11 15:00"))
-
-    assert_quantity_allclose(hpc.Ty, -66.062568 * u.arcsec)
