@@ -71,9 +71,6 @@ def test_class_creation(indirect_fixture):
 
     rot_class = type(rot_frame)
 
-    # Check that that the RotatedSunFrame metaclass is derived from the frame's metaclass
-    assert issubclass(type(rot_class), type(base_class))
-
     # Check that the RotatedSunFrame class name has both 'RotatedSun' and the name of the base
     assert 'RotatedSun' in rot_class.__name__
     assert base_class.__name__ in rot_class.__name__
@@ -81,6 +78,9 @@ def test_class_creation(indirect_fixture):
     # Check that the base class is in fact the specified class
     assert type(rot_frame.base) == base_class
 
+    # Check that the new class does *not* have the `obstime` frame attribute
+    assert 'obstime' not in rot_frame.frame_attributes
+
     # Check that one-leg transformations have been created
     assert len(frame_transform_graph.get_transform(rot_class, rot_class).transforms) == 1
     assert len(frame_transform_graph.get_transform(base_class, rot_class).transforms) == 1
@@ -94,6 +94,10 @@ def test_class_creation(indirect_fixture):
     assert not rot_frame.base.has_data
 
 
+def test_no_obstime_frame_attribute():
+    assert 'obstime' not in RotatedSunFrame.frame_attributes
+
+
 def test_as_base(rot_hgs):
     # Check the as_base() method
     a = rot_hgs[1].as_base()
