@@ -1,25 +1,14 @@
-import pytest
-import hypothesis.strategies as st
-from hypothesis import given, settings
 import numpy as np
+import pytest
+from hypothesis import given, settings
 
 import astropy.units as u
-from astropy.tests.helper import assert_quantity_allclose
 from astropy.coordinates import SkyCoord, SkyOffsetFrame
+from astropy.tests.helper import assert_quantity_allclose
 
 from sunpy.coordinates import NorthOffsetFrame
-
-
-@st.composite
-def latitude(draw, lat=st.floats(min_value=-90, max_value=90,
-                                 allow_nan=False, allow_infinity=False)):
-    return draw(lat) * u.deg
-
-
-@st.composite
-def longitude(draw, lon=st.floats(min_value=-180, max_value=180,
-                                 allow_nan=False, allow_infinity=False)):
-    return draw(lon) * u.deg
+from .helpers import assert_longitude_allclose
+from .strategies import latitudes, longitudes
 
 
 def test_null():
@@ -33,8 +22,8 @@ def test_null():
     assert off.origin.lon == 0*u.deg
 
 
-@given(lon=longitude(), lat=latitude())
-@settings(deadline=5000)
+@given(lon=longitudes(), lat=latitudes())
+@settings(deadline=1000)
 def test_transform(lon, lat):
     """
     Test that the north pole in the new frame transforms back to the given
@@ -44,14 +33,14 @@ def test_transform(lon, lat):
     off = NorthOffsetFrame(north=north)
     t_north = SkyCoord(lon=0*u.deg, lat=90*u.deg, frame=off)
     t_north = t_north.transform_to('heliographic_stonyhurst')
-    assert_quantity_allclose(north.lon, t_north.lon, atol=1e6*u.deg)
-    assert_quantity_allclose(north.lat, t_north.lat, atol=1e6*u.deg)
+    assert_longitude_allclose(north.lon, t_north.lon, atol=1e-6*u.deg)
+    assert_quantity_allclose(north.lat, t_north.lat, atol=1e-6*u.deg)
 
 
 def test_south_pole():
     s = SkyCoord(-10*u.deg, 0*u.deg, frame='heliographic_stonyhurst')
     off = NorthOffsetFrame(north=s)
-    assert_quantity_allclose(off.origin.lon, 170*u.deg)
+    assert_longitude_allclose(off.origin.lon, 170*u.deg)
     assert_quantity_allclose(off.origin.lat, -90*u.deg)
 
 
@@ -60,7 +49,7 @@ def test_cartesian():
     s = SkyCoord(1, 2, 3, unit=u.m,
                  representation_type='cartesian', frame='heliographic_stonyhurst')
     off = NorthOffsetFrame(north=s)
-    assert_quantity_allclose(off.origin.lon, np.arctan2(s.y, s.x))
+    assert_longitude_allclose(off.origin.lon, np.arctan2(s.y, s.x))
     assert_quantity_allclose(off.origin.lat, np.arctan2(s.z, np.sqrt(s.x**2 + s.y**2)) - 90*u.deg)
 
 
