@@ -1,10 +1,14 @@
-# -*- coding: utf-8 -*-
 import astropy.wcs.utils
-from astropy.wcs import WCSSUB_CELESTIAL
 from astropy.wcs import WCS
 
-from .frames import (BaseCoordinateFrame, SunPyBaseCoordinateFrame,
-                     Helioprojective, Heliocentric, HeliographicStonyhurst, HeliographicCarrington)
+from .frames import (
+    BaseCoordinateFrame,
+    Heliocentric,
+    HeliographicCarrington,
+    HeliographicStonyhurst,
+    Helioprojective,
+    SunPyBaseCoordinateFrame,
+)
 
 __all__ = ['solar_wcs_frame_mapping', 'solar_frame_to_wcs_mapping']
 
@@ -15,6 +19,9 @@ def solar_wcs_frame_mapping(wcs):
     type values in the `astropy.wcs.utils.wcs_to_celestial_frame` registry.
     """
 
+    if hasattr(wcs, "coordinate_frame"):
+        return wcs.coordinate_frame
+
     dateobs = wcs.wcs.dateobs or None
 
     # SunPy Map adds 'heliographic_observer' and 'rsun' attributes to the WCS
@@ -39,7 +46,7 @@ def solar_wcs_frame_mapping(wcs):
         return HeliographicStonyhurst(obstime=dateobs)
 
     if {'CRLN', 'CRLT'} <= ctypes:
-        return HeliographicCarrington(obstime=dateobs)
+        return HeliographicCarrington(obstime=dateobs, observer=observer)
 
     if {'SOLX', 'SOLY'} <= ctypes:
         return Heliocentric(obstime=dateobs, observer=observer)
@@ -92,5 +99,6 @@ def solar_frame_to_wcs_mapping(frame, projection='TAN'):
 
     return wcs
 
+
 astropy.wcs.utils.WCS_FRAME_MAPPINGS.append([solar_wcs_frame_mapping])
 astropy.wcs.utils.FRAME_WCS_MAPPINGS.append([solar_frame_to_wcs_mapping])
