@@ -1,15 +1,14 @@
 import os
 from pathlib import Path
-from collections import namedtuple
 from urllib.parse import urljoin
 
 from sunpy import log
 from sunpy.util.config import _is_writable_dir, get_and_create_sample_dir
 from sunpy.util.parfive_helpers import Downloader
 
-_base_urls = (
-    'http://data.sunpy.org/sunpy/v1/',
+_BASE_URLS = (
     'https://github.com/sunpy/sample-data/raw/master/sunpy/v1/',
+    'http://data.sunpy.org/sunpy/v1/',
 )
 
 # Shortcut requirements:
@@ -21,7 +20,7 @@ _base_urls = (
 # All separated by underscores
 
 # the files should include necessary extensions
-_sample_data = {
+_SAMPLE_DATA = {
     # Do roll image first because it's the largest file.
     "AIA_171_ROLL_IMAGE": "aiacalibim5.fits.gz",
     "HMI_LOS_IMAGE": "HMI20110607_063211_los_lowres.fits",
@@ -40,24 +39,67 @@ _sample_data = {
     "EIT_195_IMAGE": "eit_l1_20110607_203753.fits",
     "RHESSI_IMAGE": "hsi_image_20110607_063300.fits",
     "CALLISTO_SPECTRUM": "BIR_20110607_062400_10.fit",
-    # Not in the sample-data repo
-    # "RHESSI_EVENT_LIST": "hsi_calib_ev_20020220_1106_20020220_1106_25_40.fits",
     "SWAP_LEVEL1_IMAGE": "swap_lv1_20110607_063329.fits",
     "EVE_TIMESERIES": "20110607_EVE_L0CS_DIODES_1m.txt",
-    # Uncomment this if it needs to be used. Commented out to save bandwidth.
-    # "LYRA_LIGHTCURVE": ("lyra_20110810-000000_lev2_std.fits.gz", ,
     "LYRA_LEVEL3_TIMESERIES": "lyra_20110607-000000_lev3_std.fits",
     "GOES_XRS_TIMESERIES": "go1520110607.fits",
     "GBM_TIMESERIES": "glg_cspec_n5_110607_v00.pha",
     "RHESSI_TIMESERIES": "hsi_obssumm_20110607_025.fits",
-    "NORH_TIMESERIES": "tca110607.fits"
+    "NORH_TIMESERIES": "tca110607.fits",
 }
 
 # Reverse the dict because we want to use it backwards, but it is nicer to
 # write the other way around
-_sample_files = {v: k for k, v in _sample_data.items()}
+_SAMPLE_FILES = {v: k for k, v in _SAMPLE_DATA.items()}
 
-_error = namedtuple("error", ("filepath_partial", "url", "response"))
+
+def _download_sample_data(base_url, sample_files, overwrite):
+    """
+    Downloads a list of files.
+
+    Parameters
+    ----------
+    base_url : str
+        Base URL for each file.
+    sample_files : list of tuples
+        List of tuples that are (URL_NAME, SAVE_NAME).
+    overwrite : bool
+        Will overwrite a file on disk if True.
+
+    Returns
+    -------
+    `parfive.Results`
+        Download results. Will behave like a list of files.
+    """
+    dl = Downloader(overwrite=overwrite, progress=False)
+    for url_file_name, fname in sample_files:
+        url = urljoin(base_url, url_file_name)
+        dl.enqueue_file(url, filename=fname)
+    results = dl.download()
+    return results
+
+
+def _retry_sample_data(results):
+    # In case we have a broken file on disk, overwrite it.
+    dl = Downloader(overwrite=True, progress=False)
+    for err in results.errors:
+        file_name = err.filepath_partial().name
+        log.debug(
+            f"Failed to download {_SAMPLE_FILES[file_name]} from {err.url}: {err.exception}")
+        # Update the url to a mirror and requeue the file.
+        new_url = urljoin(_BASE_URLS[1], file_name)
+        log.debug(f"Attempting redownload of {_SAMPLE_FILES[file_name]} using {new_url}")
+        dl.enqueue_file(new_url, filename=err.filepath_partial)
+    extra_results = dl.download()
+    for err in extra_results.errors:
+        file_name = err.filepath_partial().name
+        log.debug(f"Failed to download {_SAMPLE_FILES[file_name]} from {err.url}: {err.exception}"
+                  )
+        log.error(
+            f"Failed to download {_SAMPLE_FILES[file_name]} from all mirrors,"
+            "the file will not be available."
+        )
+    return results + extra_results
 
 
 def download_sample_data(overwrite=False):
@@ -77,51 +119,21 @@ def download_sample_data(overwrite=False):
     else:
         # Creating the directory for sample files to be downloaded
         sampledata_dir = Path(get_and_create_sample_dir())
-
-    dl = Downloader(overwrite=overwrite)
-
-    first_url = _base_urls[0]
-
     already_downloaded = []
-    for file_name in _sample_files.keys():
-        url = urljoin(first_url, file_name)
-        fname = sampledata_dir/file_name
-        # We have to avoid calling download if we already have all the files.
+    to_download = []
+    for url_file_name in _SAMPLE_FILES.keys():
+        fname = sampledata_dir/url_file_name
+        # We want to avoid calling download if we already have all the files.
         if fname.exists() and not overwrite:
             already_downloaded.append(fname)
         else:
-            dl.enqueue_file(url, filename=sampledata_dir/file_name)
-
-    if dl.queued_downloads:
-        results = dl.download()
+            # URL and Filename pairs
+            to_download.append((url_file_name, fname))
+    if to_download:
+        results = _download_sample_data(_BASE_URLS[0], to_download, overwrite=overwrite)
     else:
         return already_downloaded
-
-    if not results.errors:
-        return results
-    else:
-        log.info('Failed to download one or more sample data files, retrying with a mirror.')
-
-    for retry_url in _base_urls[1:]:
-        for i, err in enumerate(results.errors):
-            file_name = err.filepath_partial().name
-            log.debug(
-                f"Failed to download {_sample_files[file_name]} from {err.url}: {err.exception}")
-            # Overwrite the parfive error to change the url to a mirror
-            new_url = urljoin(retry_url, file_name)
-            results._errors[i] = _error(err.filepath_partial,
-                                        new_url,
-                                        err.exception)
-
-        results = dl.retry(results)
-
-        if not results.errors:
-            return results
-
-    for err in results.errors:
-        file_name = err.filepath_partial().name
-        log.debug(f"Failed to download {_sample_files[file_name]} from {err.url}: {err.exception}")
-        log.error(
-            f"Failed to download {_sample_files[file_name]} from all mirrors, the file will not be available.")
-
-    return results
+    # Something went wrong.
+    if results.errors:
+        results = _retry_sample_data(results)
+    return results + already_downloaded
