@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
-from sqlalchemy import or_, and_, not_
+from sqlalchemy import and_, not_, or_
 
+from sunpy.database.tables import DatabaseEntry
+from sunpy.database.tables import FitsHeaderEntry as TableFitsHeaderEntry
+from sunpy.database.tables import Tag as TableTag
+from sunpy.net import _attrs as core_attrs
+from sunpy.net.attr import Attr, AttrAnd, AttrOr, AttrWalker, Range, SimpleAttr, ValueAttr
 from sunpy.time import parse_time
-from sunpy.net.vso import attrs as vso_attrs
-from sunpy.net.attr import (AttrWalker, Attr, ValueAttr,
-                            AttrAnd, AttrOr, SimpleAttr)
-from sunpy.database.tables import (DatabaseEntry,
-                                   Tag as TableTag,
-                                   FitsHeaderEntry as TableFitsHeaderEntry)
 
 __all__ = [
     'Starred', 'Tag', 'Path', 'DownloadTime', 'FitsHeaderEntry', 'walker']
@@ -105,13 +103,13 @@ class Path(Attr):
 
 
 # TODO: support excluding ranges as soon as
-# vso_attrs._Range.__xor__ is fixed / renamed
-class DownloadTime(Attr, vso_attrs._Range):
+# attr.Range.__xor__ is fixed / renamed
+class DownloadTime(Range):
     def __init__(self, start, end):
         self.start = parse_time(start).datetime
         self.end = parse_time(end).datetime
         self.inverted = False
-        vso_attrs._Range.__init__(self, start, end, self.__class__)
+        super().__init__(start, end)
 
     def __invert__(self):
         download_time = self.__class__(self.start, self.end)
@@ -200,9 +198,8 @@ def _create(wlk, root, session):
         elif typ == 'path':
             path, inverted = value
             if inverted:
-                # pylint: disable=E711
                 query = query.filter(or_(
-                    DatabaseEntry.path != path, DatabaseEntry.path == None))
+                    DatabaseEntry.path != path, DatabaseEntry.path == None))  # NOQA
             else:
                 query = query.filter(DatabaseEntry.path == path)
         elif typ == 'wave':
@@ -217,7 +214,8 @@ def _create(wlk, root, session):
                 DatabaseEntry.observation_time_end > start))
         else:
             if typ.lower() not in SUPPORTED_SIMPLE_VSO_ATTRS.union(SUPPORTED_NONVSO_ATTRS):
-                raise NotImplementedError(f"The attribute {typ!r} is not yet supported to query a database.")
+                raise NotImplementedError(
+                    f"The attribute {typ!r} is not yet supported to query a database.")
             query = query.filter_by(**{typ: value})
     return query.all()
 
@@ -254,12 +252,12 @@ def _convert(attr):
     return ValueAttr({(attr.__class__.__name__.lower(), ): attr.value})
 
 
-@walker.add_converter(vso_attrs.Wavelength)
+@walker.add_converter(core_attrs.Wavelength)
 def _convert(attr):
     return ValueAttr({('wave', ): (attr.min.value, attr.max.value, str(attr.unit))})
 
 
-@walker.add_converter(vso_attrs.Time)
+@walker.add_converter(core_attrs.Time)
 def _convert(attr):
     near = None if not attr.near else attr.near.datetime
     return ValueAttr({('time', ): (attr.start.datetime, attr.end.datetime, near)})
