@@ -214,9 +214,9 @@ class DatabaseEntry(DatabaseEntryType, Base):
         to a specific data product. The association of fileid to the specific
         data may change sometime, if the fileid always points to the latest
         calibrated data.
-    observation_time_start : datetime
+    observation_time_start : datetime.datetime
         The date and time when the observation of the data started.
-    observation_time_end : datetime
+    observation_time_end : datetime.datetime
         The date and time when the observation of the data ended.
     instrument : str
         The instrument which was used to observe the data.
@@ -233,7 +233,7 @@ class DatabaseEntry(DatabaseEntryType, Base):
         files they are located.
     path : str
         A local file path where the according FITS file is saved.
-    download_time : datetime
+    download_time : datetime.datetime
         The date and time when the files connected to a query have been
         downloaded. Note: this is not the date and time when this entry has
         been added to a database!
@@ -605,12 +605,12 @@ def entries_from_file(file, default_waveunit=None,
     # (which would make strptime freak out, if I remember correctly).
     """Use the headers of a FITS file to generate an iterator of
     :class:`sunpy.database.tables.DatabaseEntry` instances. Gathered
-    information will be saved in the attribute `fits_header_entries`. If the
+    information will be saved in the attribute ``fits_header_entries``. If the
     key INSTRUME, WAVELNTH or DATE-OBS / DATE_OBS is available, the attribute
-    `instrument`, `wavemin` and `wavemax` or `observation_time_start` is set,
-    respectively. If the wavelength unit can be read, the values of `wavemin`
-    and `wavemax` are converted to nm (nanometres). The value of the `file`
-    parameter is used to set the attribute `path` of each generated database
+    ``instrument``, ``wavemin`` and ``wavemax`` or ``observation_time_start`` is set,
+    respectively. If the wavelength unit can be read, the values of ``wavemin``
+    and ``wavemax`` are converted to nm (nanometres). The value of the ``file``
+    parameter is used to set the attribute ``path`` of each generated database
     entry.
 
     Parameters
@@ -627,19 +627,19 @@ def entries_from_file(file, default_waveunit=None,
     time_string_parse_format : str, optional
         Fallback timestamp format which will be passed to
         `~astropy.time.Time.strptime` if `sunpy.time.parse_time` is unable to
-        automatically read the `date-obs` metadata.
+        automatically read the ``date-obs`` metadata.
 
     Raises
     ------
-    sunpy.database.WaveunitNotFoundError
-        If `default_waveunit` is not given and the wavelength unit cannot
+    sunpy.database.tables.WaveunitNotFoundError
+        If ``default_waveunit`` is not given and the wavelength unit cannot
         be found in one of the FITS headers
 
-    sunpy.WaveunitNotConvertibleError
+    sunpy.database.tables.WaveunitNotConvertibleError
         If a wavelength unit could be found but cannot be used to create an
         instance of the type ``astropy.units.Unit``. This can be the case
-        for example if a FITS header has the key `WAVEUNIT` with the value
-        `nonsense`.
+        for example if a FITS header has the key ``WAVEUNIT`` with the value
+        ``nonsense``.
 
     Examples
     --------
@@ -725,7 +725,7 @@ def entries_from_dir(fitsdir, recursive=False, pattern='*',
                      default_waveunit=None, time_string_parse_format=None):
     """Search the given directory for FITS files and use the corresponding FITS
     headers to generate instances of :class:`DatabaseEntry`. FITS files are
-    detected by reading the content of each file, the `pattern` argument may be
+    detected by reading the content of each file, the ``pattern`` argument may be
     used to avoid reading entire directories if one knows that all FITS files
     have the same filename extension.
 
@@ -740,7 +740,7 @@ def entries_from_dir(fitsdir, recursive=False, pattern='*',
         default is `False`, i.e. the given directory is not searched
         recursively.
 
-    pattern : string, optional
+    pattern : str, optional
         The pattern can be used to filter the list of filenames before the
         files are attempted to be read. The default is to collect all files.
         This value is passed to the function :func:`fnmatch.filter`, see its
@@ -753,7 +753,7 @@ def entries_from_dir(fitsdir, recursive=False, pattern='*',
     time_string_parse_format : str, optional
         Fallback timestamp format which will be passed to
         `~astropy.time.Time.strptime` if `sunpy.time.parse_time` is unable to
-        automatically read the `date-obs` metadata.
+        automatically read the ``date-obs`` metadata.
 
     Returns
     -------
@@ -798,11 +798,11 @@ def _create_display_table(database_entries, columns=None, sort=False):
 
     Parameters
     ----------
-    database_entries : iterable of :class:`DatabaseEntry` instances
-        The database entries will be the rows in the resulting table.
+    database_entries : list
+        The :class:`DatabaseEntry`s will be the rows in the resulting table.
 
-    columns : iterable of str
-        The columns that will be displayed in the resulting table. Possible
+    columns : list
+        The column name strings that will be displayed in the resulting table. Possible
         values for the strings are all attributes of :class:`DatabaseEntry`.
 
     sort : bool (optional)
