@@ -16,8 +16,8 @@ References
    Processing and Pattern Recognition Society, Quebec City, Canada, May 15-19,
    1995, p. 120-123 http://www.scribblethink.org/Work/nvisionInterface/vi95_lewis.pdf.
 """
-from copy import deepcopy
 import warnings
+from copy import deepcopy
 
 import numpy as np
 from scipy.ndimage.interpolation import shift
@@ -27,7 +27,7 @@ import astropy.units as u
 
 import sunpy.map
 from sunpy.map.mapbase import GenericMap
-from sunpy.util import (SunpyUserWarning, SunpyDeprecationWarning, deprecated)
+from sunpy.util import SunpyDeprecationWarning, SunpyUserWarning, deprecated
 
 __all__ = ['calculate_shift', 'clip_edges', 'calculate_clipping',
            'match_template_to_layer', 'find_best_match_location',
@@ -396,7 +396,7 @@ def apply_shifts(mc, yshift: u.pix, xshift: u.pix, clip=True, **kwargs):
 
     Notes
     -----
-    All other keywords are passed to `scipy.ndimage.interpolation.shift`.
+    All other keywords are passed to `scipy.ndimage.shift`.
 
     Returns
     -------
@@ -421,8 +421,9 @@ def apply_shifts(mc, yshift: u.pix, xshift: u.pix, clip=True, **kwargs):
             shifted_data = clip_edges(shifted_data, yclips, xclips)
             new_meta['naxis1'] = shifted_data.shape[1]
             new_meta['naxis2'] = shifted_data.shape[0]
-            new_meta['crpix1'] = m.reference_pixel.x.value + xshift[i].value - xshift[0].value
-            new_meta['crpix2'] = m.reference_pixel.y.value + yshift[i].value - yshift[0].value
+            # Add one to go from zero-based to one-based indexing
+            new_meta['crpix1'] = m.reference_pixel.x.value + 1 + xshift[i].value - xshift[0].value
+            new_meta['crpix2'] = m.reference_pixel.y.value + 1 + yshift[i].value - yshift[0].value
 
         new_map = sunpy.map.Map(shifted_data, new_meta)
 
