@@ -1,45 +1,49 @@
-# -*- coding: utf-8 -*-
 """
-Provides processing routines for data captured with the AIA instrument on SDO.
+This module provides processing routines for data captured with the AIA
+instrument on SDO.
 """
 import numpy as np
+
 import astropy.units as u
 
 from sunpy.map.sources.sdo import AIAMap, HMIMap
+from sunpy.util.decorators import deprecated
 
 __all__ = ['aiaprep']
 
 
+@deprecated("2.0", alternative="`register` in aiapy (https://aiapy.readthedocs.io) for converting \
+AIA images to level 1.5")
 def aiaprep(aiamap):
     """
     Processes a level 1 `~sunpy.map.sources.sdo.AIAMap` into a level 1.5
-    `~sunpy.map.sources.sdo.AIAMap`. Rotates, scales and
-    translates the image so that solar North is aligned with the y axis, each
-    pixel is 0.6 arcsec across, and the center of the sun is at the center of
-    the image. The actual transformation is done by Map's
-    :meth:`~sunpy.map.mapbase.GenericMap.rotate` method.
+    `~sunpy.map.sources.sdo.AIAMap`.
 
-    This function is similar in functionality to aia_prep() in SSWIDL, but
+    Rotates, scales and translates the image so that solar North is aligned
+    with the y axis, each pixel is 0.6 arcsec across, and the center of the
+    Sun is at the center of the image. The actual transformation is done by Map's
+    `~sunpy.map.mapbase.GenericMap.rotate` method.
+
+    This function is similar in functionality to ``aia_prep`` in SSWIDL, but
     it does not use the same transformation to rotate the image and it handles
     the meta data differently. It should therefore not be expected to produce
     the same results.
 
     Parameters
     ----------
-    aiamap : `~sunpy.map.sources.sdo.AIAMap` instance
-        A `sunpy.map.Map` from AIA
+    aiamap : `~sunpy.map.sources.sdo.AIAMap`
+        A `sunpy.map.Map` from AIA.
 
     Returns
     -------
-    newmap : A level 1.5 copy of `~sunpy.map.sources.sdo.AIAMap`
+    `~sunpy.map.sources.sdo.AIAMap`:
+        A level 1.5 copy of `~sunpy.map.sources.sdo.AIAMap`.
 
     Notes
     -----
-    This routine makes use of Map's :meth:`~sunpy.map.mapbase.GenericMap.rotate`
-    method, which modifies the header information to the standard PCi_j WCS
-    formalism.
-    The FITS header resulting in saving a file after this procedure will
-    therefore differ from the original file.
+    This routine modifies the header information to the standard PCi_j WCS
+    formalism. The FITS header resulting in saving a file after this
+    procedure will therefore differ from the original file.
     """
 
     if not isinstance(aiamap, (AIAMap, HMIMap)):
@@ -61,7 +65,8 @@ def aiaprep(aiamap):
     center = np.floor(tempmap.meta['crpix1'])
     range_side = (center + np.array([-1, 1]) * aiamap.data.shape[0] / 2) * u.pix
     newmap = tempmap.submap(u.Quantity([range_side[0], range_side[0]]),
-                            u.Quantity([range_side[1], range_side[1]]))
+                            u.Quantity([range_side[1] - 1 * u.pix,
+                                        range_side[1] - 1 * u.pix]))
 
     newmap.meta['r_sun'] = newmap.meta['rsun_obs'] / newmap.meta['cdelt1']
     newmap.meta['lvl_num'] = 1.5
