@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 
 import os
 
@@ -7,15 +6,13 @@ import pytest
 
 import sunpy.data.test
 import sunpy.map
-
 from sunpy.instr import iris
-
-
 from sunpy.util import SunpyUserWarning
 
 
 def test_SJI_to_sequence():
-    test_data = os.path.join(sunpy.data.test.rootdir, 'iris_l2_20130801_074720_4040000014_SJI_1400_t000.fits')
+    test_data = os.path.join(sunpy.data.test.rootdir,
+                             'iris_l2_20130801_074720_4040000014_SJI_1400_t000.fits')
     iris_cube = iris.SJI_to_sequence(test_data, start=0, stop=None, hdu=0)
 
     assert isinstance(iris_cube, sunpy.map.MapSequence)
@@ -25,7 +22,8 @@ def test_SJI_to_sequence():
 
 
 def test_iris_rot():
-    test_data = os.path.join(sunpy.data.test.rootdir, 'iris_l2_20130801_074720_4040000014_SJI_1400_t000.fits')
+    test_data = os.path.join(sunpy.data.test.rootdir,
+                             'iris_l2_20130801_074720_4040000014_SJI_1400_t000.fits')
     iris_cube = iris.SJI_to_sequence(test_data, start=0, stop=None, hdu=0)
     irismap = iris_cube.maps[0]
     with pytest.warns(SunpyUserWarning, match='Missing metadata for observer'):
