@@ -1,6 +1,5 @@
 import os.path
 import datetime
-import tempfile
 
 import numpy as np
 import pandas
@@ -64,7 +63,7 @@ def test_split_series_using_lytaf():
     assert len(split) == 4
     assert is_time_equal(split[0]['subtimes'][0], parse_time((2010, 6, 13, 2, 0)))
     assert is_time_equal(split[0]['subtimes'][-1], parse_time((2010, 6, 13, 2, 7, 2)))
-    assert is_time_equal(split[3]['subtimes'][0], parse_time((2010, 6, 13, 2, 59, 42)))
+    assert is_time_equal(split[3]['subtimes'][0], parse_time((2010, 6, 13, 2, 59, 41)))
     assert is_time_equal(split[3]['subtimes'][-1], parse_time((2010, 6, 13, 2, 59, 58)))
 
     # Test case when no LYTAF events found in time series.
@@ -122,7 +121,7 @@ def test_remove_lytaf_events_from_timeseries(lyra_ts):
                                                 "CHANNEL3": channels[2],
                                                 "CHANNEL4": channels[3]})
     # Assert expected result is returned
-    pandas.util.testing.assert_frame_equal(ts_test.data, dataframe_expected)
+    pandas.testing.assert_frame_equal(ts_test.data, dataframe_expected)
     assert artifact_status_test.keys() == artifact_status_expected.keys()
     np.testing.assert_array_equal(artifact_status_test["lytaf"],
                                   artifact_status_expected["lytaf"])
@@ -140,7 +139,7 @@ def test_remove_lytaf_events_from_timeseries(lyra_ts):
             lyra_ts, artifacts=["LAR", "Offpoint"],
             force_use_local_lytaf=True)
     # Assert expected result is returned
-    pandas.util.testing.assert_frame_equal(ts_test.data, dataframe_expected)
+    pandas.testing.assert_frame_equal(ts_test.data, dataframe_expected)
 
 
 @pytest.fixture()
@@ -176,7 +175,7 @@ def test_remove_lytaf_events_1(local_cache):
                                  "not_removed": LYTAF_TEST[1],
                                  "not_found": ["Offpoint"]}
     # Assert test values are same as expected
-    assert time_test.all() == time_expected.all()
+    assert (time_test == time_expected).all()
     assert (channels_test[0]).all() == (channels_expected[0]).all()
     assert (channels_test[1]).all() == (channels_expected[1]).all()
     assert artifacts_status_test.keys() == artifacts_status_expected.keys()
@@ -197,7 +196,7 @@ def test_remove_lytaf_events_1(local_cache):
             TIME, artifacts=["LAR", "Offpoint"],
             return_artifacts=True, force_use_local_lytaf=True)
     # Assert test values are same as expected
-    assert time_test.all() == time_expected.all()
+    assert (time_test == time_expected).all()
     assert artifacts_status_test.keys() == artifacts_status_expected.keys()
     np.testing.assert_array_equal(artifacts_status_test["lytaf"],
                                   artifacts_status_expected["lytaf"])
