@@ -1,6 +1,8 @@
 import os
+import pathlib
 
 import numpy as np
+import pytest
 
 import sunpy
 import sunpy.data.test
@@ -40,7 +42,8 @@ class TestFiletools:
     def test_read_file_fits_gzip(self):
         # Test read gzipped fits file
         for fits_extension in [".fts", ".fit", ".fits"]:
-            pair = sunpy.io.read_file(os.path.join(sunpy.data.test.rootdir, f"gzip_test{fits_extension}.gz"))
+            pair = sunpy.io.read_file(os.path.join(
+                sunpy.data.test.rootdir, f"gzip_test{fits_extension}.gz"))
             assert isinstance(pair, list)
             assert len(pair) == 1
             assert len(pair[0]) == 2
@@ -71,15 +74,17 @@ class TestFiletools:
     def test_read_file_header_jp2(self):
         # Test jp2
         hlist = sunpy.io.read_file_header(os.path.join(sunpy.data.test.rootdir,
-                                          "2013_06_24__17_31_30_84__SDO_AIA_AIA_193.jp2"))
+                                                       "2013_06_24__17_31_30_84__SDO_AIA_AIA_193.jp2"))
         assert isinstance(hlist, list)
         assert len(hlist) == 1
         assert isinstance(hlist[0], sunpy.io.header.FileHeader)
 
-    def test_write_file_fits(self):
+    @pytest.mark.parametrize('fname', ['aia_171_image.fits',
+                                       pathlib.Path('aia_171_image.fits')])
+    def test_write_file_fits(self, fname):
         # Test write FITS
         aiapair = sunpy.io.read_file(AIA_171_IMAGE)[0]
-        sunpy.io.write_file("aia_171_image.fits", aiapair[0], aiapair[1],
+        sunpy.io.write_file(fname, aiapair[0], aiapair[1],
                             overwrite=True)
         assert os.path.exists("aia_171_image.fits")
         outpair = sunpy.io.read_file(AIA_171_IMAGE)[0]
