@@ -1,10 +1,13 @@
-"""SunPy Maps"""
-from sunpy.map.mapbase import GenericMap  # isort:skip
+"""
+SunPy Map
+
+isort:skip_file
+"""
+from sunpy.map.mapbase import GenericMap
 
 from sunpy.map import sources
 from sunpy.map.header_helper import *
 from sunpy.map.map_factory import Map
 from sunpy.map.maputils import *
-
 from .compositemap import CompositeMap
 from .mapsequence import MapSequence
