@@ -1,35 +1,33 @@
 import os
-from collections import OrderedDict
-import warnings
-import pathlib
 import glob
+import pathlib
+import warnings
+from collections import OrderedDict
+from urllib.request import Request, urlopen
 
 import numpy as np
+
 import astropy.io.fits
 from astropy.wcs import WCS
 
-import sunpy
 from sunpy import log
-from sunpy.map.mapbase import GenericMap, MapMetaValidationError
-from sunpy.map.compositemap import CompositeMap
-from sunpy.map.mapsequence import MapSequence
-
 from sunpy.data import cache
-
 from sunpy.io.file_tools import read_file
 from sunpy.io.header import FileHeader
-
+from sunpy.map.compositemap import CompositeMap
+from sunpy.map.mapbase import GenericMap, MapMetaValidationError
+from sunpy.map.mapsequence import MapSequence
 from sunpy.util import expand_list
+from sunpy.util.datatype_factory_base import (
+    BasicRegistrationFactory,
+    MultipleMatchError,
+    NoMatchError,
+    ValidationFunctionError,
+)
+from sunpy.util.functools import seconddispatch
 from sunpy.util.metadata import MetaDict
-from sunpy.util.exceptions import SunpyDeprecationWarning
 from sunpy.util.types import DatabaseEntryType
 
-from sunpy.util.datatype_factory_base import BasicRegistrationFactory
-from sunpy.util.datatype_factory_base import NoMatchError
-from sunpy.util.datatype_factory_base import MultipleMatchError
-from sunpy.util.datatype_factory_base import ValidationFunctionError
-from urllib.request import urlopen
-
 SUPPORTED_ARRAY_TYPES = (np.ndarray,)
 try:
     import dask.array
@@ -37,19 +35,47 @@ try:
 except ImportError:
     pass
 
-__authors__ = ["Russell Hewett, Stuart Mumford"]
-__email__ = "stuart@mumford.me.uk"
-
 __all__ = ['Map', 'MapFactory']
 
 
 class MapFactory(BasicRegistrationFactory):
     """
-    Map(\\*args, \\*\\*kwargs)
+    A factory for generating coordinate aware 2D images.
 
-    Map factory class.  Used to create a variety of Map objects.  Valid map types
-    are specified by registering them with the factory.
+    This factory takes a variety of inputs, such as file paths, wildcard
+    patterns or (data, header) pairs.
 
+    Depending on the input different return types are possible.
+
+    Parameters
+    ----------
+    \\*inputs
+        Inputs to parse for map objects. See the examples section for a
+        detailed list of accepted inputs.
+
+    sequence : `bool`, optional
+        Return a `sunpy.map.MapSequence` object comprised of all the parsed maps.
+
+    composite : `bool`, optional
+        Return a `sunpy.map.CompositeMap` object comprised of all the parsed maps.
+
+    Returns
+    -------
+    `sunpy.map.GenericMap`
+        If the input results in a singular map object, then that is returned.
+
+    `list` of `~sunpy.map.GenericMap`
+        If multiple inputs are given and ``sequence=False`` and ``composite=False``
+        (the default) then a list of `~sunpy.map.GenericMap` objects will be
+        returned.
+
+    `sunpy.map.MapSequence`
+        If the input corresponds to multiple maps and ``sequence=True`` is set,
+        then a `~sunpy.map.MapSequence` object is returned.
+
+    `sunpy.map.CompositeMap`
+        If the input corresponds to multiple maps and ``composite=True`` is set,
+        then a `~sunpy.map.CompositeMap` object is returned.
 
     Examples
     --------
@@ -120,18 +146,22 @@ class MapFactory(BasicRegistrationFactory):
     * Any mixture of the above not in a list
 
     >>> mymap = sunpy.map.Map(((data, header), data2, header2, 'file1.fits', url_str, 'eit_*.fits'))  # doctest: +SKIP
-    """  # noqa
+    """
 
     def _read_file(self, fname, **kwargs):
-        """ Read in a file name and return the list of (data, meta) pairs in
-            that file. """
-
-        # File gets read here.  This needs to be generic enough to seamlessly
+        """
+        Read in a file name and return the list of (data, meta) pairs in that file.
+        """
+        # File gets read here. This needs to be generic enough to seamlessly
         # call a fits file or a jpeg2k file, etc
         # NOTE: use os.fspath so that fname can be either a str or pathlib.Path
         # This can be removed once read_file supports pathlib.Path
         log.debug(f'Reading {fname}')
-        pairs = read_file(os.fspath(fname), **kwargs)
+        try:
+            pairs = read_file(os.fspath(fname), **kwargs)
+        except Exception as e:
+            msg = f"Failed to read {fname}."
+            raise IOError(msg) from e
 
         new_pairs = []
         for pair in pairs:
@@ -157,8 +187,9 @@ class MapFactory(BasicRegistrationFactory):
 
     def _parse_args(self, *args, **kwargs):
         """
-        Parses an args list for data-header pairs.  args can contain any
-        mixture of the following entries:
+        Parses an args list into data-header pairs.
+
+        args can contain any mixture of the following entries:
         * tuples of data,header
         * data, header not in a tuple
         * data, wcs object in a tuple
@@ -177,72 +208,91 @@ class MapFactory(BasicRegistrationFactory):
                          'file4',
                          'directory1',
                          '*.fits')
-
         """
-
-        data_header_pairs = list()
-        already_maps = list()
-
         # Account for nested lists of items
         args = expand_list(args)
 
-        # For each of the arguments, handle each of the cases
+        # Sanitise the input so that each 'type' of input corresponds to a different
+        # class, so single dispatch can be used later
+        nargs = len(args)
         i = 0
-        while i < len(args):
-
+        while i < nargs:
             arg = args[i]
-
-            # Data-header or data-WCS pair
             if isinstance(arg, SUPPORTED_ARRAY_TYPES):
-                arg_header = args[i+1]
-                if isinstance(arg_header, WCS):
-                    arg_header = args[i+1].to_header()
-
-                if self._validate_meta(arg_header):
-                    pair = (args[i], OrderedDict(arg_header))
-                    data_header_pairs.append(pair)
-                    i += 1    # an extra increment to account for the data-header pairing
-
-            # A database Entry
-            elif isinstance(arg, DatabaseEntryType):
-                data_header_pairs += self._read_file(arg.path, **kwargs)
-
-            # Already a Map
-            elif isinstance(arg, GenericMap):
-                already_maps.append(arg)
-
-            # URL
+                # The next two items are data and a header
+                data = args.pop(i)
+                header = args.pop(i)
+                args.insert(i, (data, header))
+                nargs -= 1
             elif isinstance(arg, str) and _is_url(arg):
-                url = arg
-                path = str(cache.download(url).absolute())
-                pairs = self._read_file(path, **kwargs)
-                data_header_pairs += pairs
-
-            # File system path (file or directory or glob)
+                # Repalce URL string with a Request object to dispatch on later
+                args[i] = Request(arg)
             elif _possibly_a_path(arg):
-                path = pathlib.Path(arg).expanduser()
-                if _is_file(path):
-                    pairs = self._read_file(path, **kwargs)
-                    data_header_pairs += pairs
-                elif _is_dir(path):
-                    for afile in sorted(path.glob('*')):
-                        data_header_pairs += self._read_file(afile, **kwargs)
-                elif glob.glob(os.path.expanduser(arg)):
-                    for afile in sorted(glob.glob(os.path.expanduser(arg))):
-                        data_header_pairs += self._read_file(afile, **kwargs)
-
-                else:
-                    raise ValueError(f'Did not find any files at {arg}')
-
-            else:
-                raise ValueError(f"Invalid input: {arg}")
-
+                # Repalce path strings with Path objects
+                args[i] = pathlib.Path(arg)
             i += 1
 
-        # TODO:
-        # In the end, if there are already maps it should be put in the same
-        # order as the input, currently they are not.
-        return data_header_pairs, already_maps
+        # Parse the arguments
+        # Note that this list can also contain GenericMaps if they are directly given to the factory
+        data_header_pairs = []
+        for arg in args:
+            data_header_pairs += self._parse_arg(arg, **kwargs)
+
+        return data_header_pairs
+
+    # Note that post python 3.8 this can be @functools.singledispatchmethod
+    @seconddispatch
+    def _parse_arg(self, arg, **kwargs):
+        """
+        Take a factory input and parse into (data, header) pairs.
+        Must return a list, even if only one pair is returned.
+        """
+        raise ValueError(f"Invalid input: {arg}")
+
+    @_parse_arg.register(tuple)
+    def _parse_tuple(self, arg, **kwargs):
+        # Data-header or data-WCS pair
+        data, header = arg
+        if isinstance(header, WCS):
+            header = header.to_header()
+
+        pair = data, header
+        if self._validate_meta(header):
+            pair = (data, OrderedDict(header))
+        return [pair]
+
+    @_parse_arg.register(DatabaseEntryType)
+    def _parse_dbase(self, arg, **kwargs):
+        return self._read_file(arg.path, **kwargs)
+
+    @_parse_arg.register(GenericMap)
+    def _parse_map(self, arg, **kwargs):
+        return [arg]
+
+    @_parse_arg.register(Request)
+    def _parse_url(self, arg, **kwargs):
+        url = arg.full_url
+        path = str(cache.download(url).absolute())
+        pairs = self._read_file(path, **kwargs)
+        return pairs
+
+    @_parse_arg.register(pathlib.Path)
+    def _parse_path(self, arg, **kwargs):
+        path = arg.expanduser()
+        if _is_file(path):
+            return self._read_file(path, **kwargs)
+        elif _is_dir(path):
+            pairs = []
+            for afile in sorted(path.glob('*')):
+                pairs += self._read_file(afile, **kwargs)
+            return pairs
+        elif glob.glob(os.path.expanduser(arg)):
+            pairs = []
+            for afile in sorted(glob.glob(os.path.expanduser(arg))):
+                pairs += self._read_file(afile, **kwargs)
+            return pairs
+        else:
+            raise ValueError(f'Did not find any files at {arg}')
 
     def __call__(self, *args, composite=False, sequence=False, silence_errors=False, **kwargs):
         """ Method for running the factory. Takes arbitrary arguments and
@@ -250,7 +300,7 @@ class MapFactory(BasicRegistrationFactory):
         to determine which is the correct Map-type to build.
 
         Arguments args and kwargs are passed through to the validation
-        function and to the constructor for the final type.  For Map types,
+        function and to the constructor for the final type. For Map types,
         validation function must take a data-header pair as an argument.
 
         Parameters
@@ -258,11 +308,9 @@ class MapFactory(BasicRegistrationFactory):
         composite : `bool`, optional
             Indicates if collection of maps should be returned as a `~sunpy.map.CompositeMap`.
             Default is `False`.
-
         sequence : `bool`, optional
             Indicates if collection of maps should be returned as a `sunpy.map.MapSequence`.
             Default is `False`.
-
         silence_errors : `bool`, optional
             If set, ignore data-header pairs which cause an exception.
             Default is ``False``.
@@ -272,29 +320,26 @@ class MapFactory(BasicRegistrationFactory):
         Extra keyword arguments are passed through to `sunpy.io.read_file` such
         as `memmap` for FITS files.
         """
-
-        data_header_pairs, already_maps = self._parse_args(*args, **kwargs)
-
+        data_header_pairs = self._parse_args(*args, **kwargs)
         new_maps = list()
 
         # Loop over each registered type and check to see if WidgetType
         # matches the arguments.  If it does, use that type.
         for pair in data_header_pairs:
+            if isinstance(pair, GenericMap):
+                new_maps.append(pair)
+                continue
             data, header = pair
             meta = MetaDict(header)
 
             try:
                 new_map = self._check_registered_widgets(data, meta, **kwargs)
                 new_maps.append(new_map)
-            except (NoMatchError, MultipleMatchError, ValidationFunctionError):
+            except (NoMatchError, MultipleMatchError,
+                    ValidationFunctionError, MapMetaValidationError) as e:
                 if not silence_errors:
                     raise
-            except MapMetaValidationError as e:
                 warnings.warn(f"One of the data, header pairs failed to validate with: {e}")
-            except Exception:
-                raise
-
-        new_maps += already_maps
 
         if not len(new_maps):
             raise RuntimeError('No maps loaded')
@@ -330,9 +375,10 @@ class MapFactory(BasicRegistrationFactory):
             else:
                 candidate_widget_types = [self.default_widget_type]
         elif n_matches > 1:
-            raise MultipleMatchError("Too many candidate types identified ({})."
-                                     "Specify enough keywords to guarantee unique type"
-                                     "identification.".format(n_matches))
+            raise MultipleMatchError("Too many candidate types identified "
+                                     f"({candidate_widget_types}). "
+                                     "Specify enough keywords to guarantee unique type "
+                                     "identification.")
 
         # Only one is found
         WidgetType = candidate_widget_types[0]
@@ -354,7 +400,7 @@ def _possibly_a_path(arg):
     Does *not* check if the path exists.
     """
     try:
-        is_path = pathlib.Path(arg)
+        pathlib.Path(arg)
         return True
     except Exception:
         return False
@@ -381,19 +427,16 @@ def _is_dir(path):
 class InvalidMapInput(ValueError):
     """Exception to raise when input variable is not a Map instance and does
     not point to a valid Map input file."""
-    pass
 
 
 class InvalidMapType(ValueError):
     """Exception to raise when an invalid type of map is requested with Map
     """
-    pass
 
 
 class NoMapsFound(ValueError):
     """Exception to raise when input does not point to any valid maps or files
     """
-    pass
 
 
 Map = MapFactory(registry=GenericMap._registry, default_widget_type=GenericMap,
