@@ -286,7 +286,9 @@ class GenericMap(NDData):
             bad_pixel_text += ", ".join(text_list)
 
         # Use a grayscale colormap with histogram equalization (and red for bad values)
-        cmap = cm.get_cmap('gray')
+        # Make a copy of the colormap to avoid modifying the matplotlib instance when
+        # doing set_bad()
+        cmap = copy.copy(cm.get_cmap('gray'))
         cmap.set_bad(color='red')
         norm = ImageNormalize(stretch=HistEqStretch(finite_data))
 
@@ -426,8 +428,9 @@ class GenericMap(NDData):
             warnings.simplefilter("ignore", SunpyUserWarning)
             try:
                 w2 = astropy.wcs.WCS(header=self.fits_header, _do_set=False)
-            except Exception:
-                warnings.warn("Unable to treat `.meta` as a FITS header, assuming a simple WCS.")
+            except Exception as e:
+                warnings.warn("Unable to treat `.meta` as a FITS header, assuming a simple WCS. "
+                              f"The exception raised was:\n{e}")
                 w2 = astropy.wcs.WCS(naxis=2)
 
         # If the FITS header is > 2D pick the first 2 and move on.
@@ -602,7 +605,11 @@ class GenericMap(NDData):
 
     @property
     def date(self):
-        """Image observation time."""
+        """
+        Image observation time.
+
+        This is taken from the 'DATE-OBS' FITS keyword.
+        """
         time = self.meta.get('date-obs', None)
         if time is None:
             if self._default_time is None:
@@ -616,12 +623,20 @@ class GenericMap(NDData):
 
     @property
     def detector(self):
-        """Detector name."""
+        """
+        Detector name.
+
+        This is taken from the 'DETECTOR' FITS keyword.
+        """
         return self.meta.get('detector', "")
 
     @property
     def exposure_time(self):
-        """Exposure time of the image in seconds."""
+        """
+        Exposure time of the image in seconds.
+
+        This is taken from the 'EXPTIME' FITS keyword.
+        """
         return self.meta.get('exptime', 0.0) * u.s
 
     @property
@@ -631,13 +646,22 @@ class GenericMap(NDData):
 
     @property
     def measurement(self):
-        """Measurement name, defaults to the wavelength of image."""
+        """
+        Measurement wavelength.
+
+        This is taken from the 'WAVELNTH' FITS keyword. If the keyword is not
+        present, defaults to 0.
+        """
         return u.Quantity(self.meta.get('wavelnth', 0),
                           self.waveunit)
 
     @property
     def waveunit(self):
-        """The `~astropy.units.Unit` of the wavelength of this observation."""
+        """
+        The `~astropy.units.Unit` of the wavelength of this observation.
+
+        This is taken from the 'WAVEUNIT' FITS keyword.
+        """
         unit = self.meta.get("waveunit")
         if unit is None:
             return u.one
@@ -645,13 +669,21 @@ class GenericMap(NDData):
 
     @property
     def wavelength(self):
-        """Wavelength of the observation."""
+        """
+        Wavelength of the observation.
+
+        This is taken from the 'WAVELNTH' FITS keyword.
+        """
         return u.Quantity(self.meta.get('wavelnth', 0),
                           self.waveunit)
 
     @property
     def observatory(self):
-        """Observatory or Telescope name."""
+        """
+        Observatory or Telescope name.
+
+        This is taken from the 'OBSRVTRY' FITS keyword.
+        """
         return self.meta.get('obsrvtry',
                              self.meta.get('telescop', "")).replace("_", " ")
 
@@ -659,6 +691,8 @@ class GenericMap(NDData):
     def processing_level(self):
         """
         Returns the FITS processing level if present.
+
+        This is taken from the 'LVL_NUM' FITS keyword.
         """
         return self.meta.get('lvl_num', None)
 
@@ -738,18 +772,29 @@ class GenericMap(NDData):
 
     @property
     def rsun_obs(self):
-        """Radius of the Sun."""
+        """
+        Angular radius of the Sun.
+
+        Notes
+        -----
+        This value is taken the ``'rsun_obs'``, ``'solar_r'``, or ``radius``
+        FITS keywords. If none of these keys are present the photospheric limb
+        as seen from the observer coordinate is returned.
+        """
         rsun_arcseconds = self.meta.get('rsun_obs',
                                         self.meta.get('solar_r',
                                                       self.meta.get('radius',
                                                                     None)))
 
         if rsun_arcseconds is None:
-            warnings.warn("Missing metadata for solar radius: assuming photospheric limb as seen from Earth.",
+            warnings.warn("Missing metadata for solar angular radius: assuming photospheric limb "
+                          "as seen from observer coordinate.",
                           SunpyUserWarning)
-            rsun_arcseconds = sun.angular_radius(self.date).to('arcsec').value
-
-        return u.Quantity(rsun_arcseconds, 'arcsec')
+            dsun = self.dsun
+            rsun = sun._angular_radius(constants.radius, dsun)
+        else:
+            rsun = rsun_arcseconds * u.arcsec
+        return rsun
 
     @property
     def coordinate_system(self):
@@ -808,7 +853,7 @@ class GenericMap(NDData):
                     fake_observer = HeliographicStonyhurst(0*u.deg, 0*u.deg, sc.radius,
                                                            obstime=sc.obstime)
                     fake_frame = sc.frame.replicate(observer=fake_observer)
-                    hgs = fake_frame.transform_to(HeliographicStonyhurst)
+                    hgs = fake_frame.transform_to(HeliographicStonyhurst(obstime=sc.obstime))
 
                     # HeliographicStonyhurst doesn't need an observer, but adding the observer
                     # facilitates a conversion back to HeliographicCarrington
@@ -907,9 +952,14 @@ class GenericMap(NDData):
 
     @property
     def rotation_matrix(self):
-        """
+        r"""
         Matrix describing the rotation required to align solar North with
         the top of the image.
+
+        The order or precendence of FITS keywords which this is taken from is:
+        - PC\*_\*
+        - CD\*_\*
+        - CROTA\*
         """
         if 'PC1_1' in self.meta:
             return np.array([[self.meta['PC1_1'], self.meta['PC1_2']],
@@ -1021,10 +1071,18 @@ class GenericMap(NDData):
                           SunpyUserWarning)
 
 # #### Data conversion routines #### #
+
+    @staticmethod
+    def _check_origin(origin):
+        """
+        Check origin is valid.
+        """
+        if origin not in [None, 0, 1]:
+            raise ValueError('origin must be 0 or 1.')
+
     def world_to_pixel(self, coordinate, origin=0):
         """
-        Convert a world (data) coordinate to a pixel coordinate by using
-        `~astropy.wcs.WCS.wcs_world2pix`.
+        Convert a world (data) coordinate to a pixel coordinate.
 
         Parameters
         ----------
@@ -1035,7 +1093,6 @@ class GenericMap(NDData):
             Origin of the top-left corner. i.e. count from 0 or 1.
             Normally, origin should be 0 when passing numpy indices, or 1 if
             passing values from FITS header or map attributes.
-            See `~astropy.wcs.WCS.wcs_world2pix` for more information.
 
         Returns
         -------
@@ -1050,21 +1107,21 @@ class GenericMap(NDData):
             raise ValueError(
                 "world_to_pixel takes a Astropy coordinate frame or SkyCoord instance.")
 
-        native_frame = coordinate.transform_to(self.coordinate_frame)
-        lon, lat = u.Quantity(self._get_lon_lat(native_frame)).to(u.deg)
-        x, y = self.wcs.wcs_world2pix(lon, lat, origin)
+        self._check_origin(origin)
+        x, y = self.wcs.world_to_pixel(coordinate)
+        if origin == 1:
+            x += 1
+            y += 1
 
         return PixelPair(x * u.pixel, y * u.pixel)
 
     @u.quantity_input
     def pixel_to_world(self, x: u.pixel, y: u.pixel, origin=0):
         """
-        Convert a pixel coordinate to a data (world) coordinate by using
-        `~astropy.wcs.WCS.wcs_pix2world`.
+        Convert a pixel coordinate to a data (world) coordinate.
 
         Parameters
         ----------
-
         x : `~astropy.units.Quantity`
             Pixel coordinate of the CTYPE1 axis. (Normally solar-x).
 
@@ -1075,28 +1132,18 @@ class GenericMap(NDData):
             Origin of the top-left corner. i.e. count from 0 or 1.
             Normally, origin should be 0 when passing numpy indices, or 1 if
             passing values from FITS header or map attributes.
-            See `~astropy.wcs.WCS.wcs_pix2world` for more information.
 
         Returns
         -------
-
         coord : `astropy.coordinates.SkyCoord`
             A coordinate object representing the output coordinate.
-
         """
+        self._check_origin(origin)
+        if origin == 1:
+            x = x - 1 * u.pixel
+            y = y - 1 * u.pixel
 
-        # Hold the WCS instance here so we can inspect the output units after
-        # the pix2world call
-        temp_wcs = self.wcs
-
-        x, y = temp_wcs.wcs_pix2world(x, y, origin)
-
-        out_units = list(map(u.Unit, temp_wcs.wcs.cunit))
-
-        x = u.Quantity(x, out_units[0])
-        y = u.Quantity(y, out_units[1])
-
-        return SkyCoord(x, y, frame=self.coordinate_frame)
+        return self.wcs.pixel_to_world(x, y)
 
 # #### I/O routines #### #
 
@@ -1112,9 +1159,9 @@ class GenericMap(NDData):
             Location to save file to.
         filetype : str
             'auto' or any supported file extension.
-        hdu_type: None, `~fits.CompImageHDU`
+        hdu_type: None, `~astropy.io.fits.CompImageHDU`
             `None` will return a normal FITS file.
-            `~fits.CompImageHDU` will rice compress the FITS file.
+            `~astropy.io.fits.CompImageHDU` will rice compress the FITS file.
         kwargs :
             Any additional keyword arguments are passed to
             `~sunpy.io.write_file`.
@@ -1145,7 +1192,7 @@ class GenericMap(NDData):
                   `scipy.interpolate.interp1d`.
                 * ``'spline'`` - Uses piecewise polynomials (splines) for mapping the input
                   array to new coordinates by interpolation using
-                  `ndimage.map_coordinates`.
+                  `scipy.ndimage.map_coordinates`.
 
         Returns
         -------
@@ -1187,6 +1234,8 @@ class GenericMap(NDData):
         lon, lat = self._get_lon_lat(self.center.frame)
         new_meta['crval1'] = lon.value
         new_meta['crval2'] = lat.value
+        new_meta['naxis1'] = new_data.shape[1]
+        new_meta['naxis2'] = new_data.shape[0]
 
         # Create new map instance
         new_map = self._new_instance(new_data, new_meta, self.plot_settings)
@@ -1212,14 +1261,15 @@ class GenericMap(NDData):
         ----------
         angle : `~astropy.units.Quantity`
             The angle (degrees) to rotate counterclockwise.
-        rmatrix : 2x2
-            Linear transformation rotation matrix.
-        order : int 0-5
-            Interpolation order to be used. When using scikit-image this
+        rmatrix : ndarray
+            2x2 linear transformation rotation matrix.
+        order : int
+            Interpolation order to be used. Must be in the range 0-5.
+            When using scikit-image this
             parameter is passed into :func:`skimage.transform.warp` (e.g., 4
             corresponds to bi-quartic interpolation).
             When using scipy it is passed into
-            :func:`scipy.ndimage.interpolation.affine_transform` where it
+            :func:`scipy.ndimage.affine_transform` where it
             controls the order of the spline. Faster performance may be
             obtained at the cost of accuracy by using lower values.
             Default: 4
@@ -1233,7 +1283,7 @@ class GenericMap(NDData):
             Default: 0.0
         use_scipy : bool
             If True, forces the rotation to use
-            :func:`scipy.ndimage.interpolation.affine_transform`, otherwise it
+            :func:`scipy.ndimage.affine_transform`, otherwise it
             uses the :func:`skimage.transform.warp`.
             Default: False, unless scikit-image can't be imported
 
@@ -1384,15 +1434,17 @@ class GenericMap(NDData):
         Returns a submap defined by a rectangle.
 
         Any pixels which have at least part of their area inside the rectangle
-        are returned.
+        are returned. If the rectangle is defined in world coordinates, the
+        smallest array which contains all four corners of the rectangle as
+        defined in world coordinates is returned.
 
         Parameters
         ----------
         bottom_left : `astropy.units.Quantity` or `~astropy.coordinates.SkyCoord`
-            The bottom-left coordinate of the rectangle. If a `SkyCoord` it can
+            The bottom-left coordinate of the rectangle. If a `~astropy.coordinates.SkyCoord` it can
             have shape ``(2,)`` and simultaneously define ``top_right``. If specifying
             pixel coordinates it must be given as an `~astropy.units.Quantity`
-            object with units of `~astropy.units.pixel`.
+            object with units of `~astropy.units.pix`.
         top_right : `astropy.units.Quantity` or `~astropy.coordinates.SkyCoord`, optional
             The top-right coordinate of the rectangle. If ``top_right`` is
             specified ``width`` and ``height`` must be omitted.
@@ -1409,6 +1461,12 @@ class GenericMap(NDData):
             A new map instance is returned representing to specified
             sub-region.
 
+        Notes
+        -----
+        When specifying pixel coordinates, they are specified in Cartesian
+        order not in numpy order. So, for example, the ``bottom_left=``
+        argument should be ``[left, bottom]``.
+
         Examples
         --------
         >>> import astropy.units as u
@@ -1422,58 +1480,37 @@ class GenericMap(NDData):
         <sunpy.map.sources.sdo.AIAMap object at 0x...>
         SunPy Map
         ---------
-        Observatory:		 SDO
-        Instrument:		 AIA 3
-        Detector:		 AIA
-        Measurement:		 171.0 Angstrom
-        Wavelength:		 171.0 Angstrom
-        Observation Date:	 2011-06-07 06:33:02
-        Exposure Time:		 0.234256 s
-        Dimension:		 [334. 334.] pix
-        Coordinate System:	 helioprojective
-        Scale:			 [2.402792 2.402792] arcsec / pix
-        Reference Pixel:	 [127.5 126.5] pix
-        Reference Coord:	 [3.22309951 1.38578135] arcsec
-        array([[ 450.4546 ,  565.81494,  585.0416 , ..., 1178.3234 , 1005.28284,
-                977.8161 ],
-            [ 474.20004,  516.1865 ,  555.7032 , ..., 1024.9636 , 1010.1449 ,
-                1010.1449 ],
-            [ 548.1609 ,  620.9256 ,  620.9256 , ...,  933.8139 , 1074.4924 ,
-                1108.4492 ],
-                ...,
-            [ 203.58617,  195.52335,  225.75891, ...,  612.7742 ,  580.52295,
-                560.3659 ],
-            [ 206.00058,  212.1806 ,  232.78065, ...,  650.96185,  622.12177,
-                537.6615 ],
-            [ 229.32516,  236.07002,  222.5803 , ...,  517.1058 ,  586.8026 ,
-                591.2992 ]], dtype=float32)
+        Observatory:         SDO
+        Instrument:          AIA 3
+        Detector:            AIA
+        Measurement:         171.0 Angstrom
+        Wavelength:          171.0 Angstrom
+        Observation Date:    2011-06-07 06:33:02
+        Exposure Time:       0.234256 s
+        Dimension:           [335. 335.] pix
+        Coordinate System:   helioprojective
+        Scale:               [2.402792 2.402792] arcsec / pix
+        Reference Pixel:     [126.5 125.5] pix
+        Reference Coord:     [3.22309951 1.38578135] arcsec
+        ...
 
         >>> aia.submap([0,0]*u.pixel, [5,5]*u.pixel)   # doctest: +REMOTE_DATA
         <sunpy.map.sources.sdo.AIAMap object at 0x...>
         SunPy Map
         ---------
-        Observatory:		 SDO
-        Instrument:		 AIA 3
-        Detector:		 AIA
-        Measurement:		 171.0 Angstrom
-        Wavelength:		 171.0 Angstrom
-        Observation Date:	 2011-06-07 06:33:02
-        Exposure Time:		 0.234256 s
-        Dimension:		 [5. 5.] pix
-        Coordinate System:	 helioprojective
-        Scale:			 [2.402792 2.402792] arcsec / pix
-        Reference Pixel:	 [512.5 512.5] pix
-        Reference Coord:	 [3.22309951 1.38578135] arcsec
-        array([[-95.92475   ,   7.076416  ,  -1.9656711 ,  -2.9485066 ,
-                -0.98283553],
-            [-96.97533   ,  -5.1167884 ,   0.        ,   0.        ,
-                0.9746264 ],
-            [-93.99607   ,   1.0189276 ,  -4.0757103 ,   2.0378551 ,
-                -2.0378551 ],
-            [-96.97533   ,  -8.040668  ,  -2.9238791 ,  -5.1167884 ,
-                -0.9746264 ],
-            [-95.92475   ,   6.028058  ,  -4.9797    ,  -1.0483578 ,
-                -3.9313421 ]], dtype=float32)
+        Observatory:         SDO
+        Instrument:          AIA 3
+        Detector:            AIA
+        Measurement:         171.0 Angstrom
+        Wavelength:          171.0 Angstrom
+        Observation Date:    2011-06-07 06:33:02
+        Exposure Time:       0.234256 s
+        Dimension:           [6. 6.] pix
+        Coordinate System:   helioprojective
+        Scale:               [2.402792 2.402792] arcsec / pix
+        Reference Pixel:     [511.5 511.5] pix
+        Reference Coord:     [3.22309951 1.38578135] arcsec
+        ...
 
         >>> width = 10 * u.arcsec
         >>> height = 10 * u.arcsec
@@ -1481,45 +1518,38 @@ class GenericMap(NDData):
         <sunpy.map.sources.sdo.AIAMap object at 0x7f91aecc5438>
         SunPy Map
         ---------
-        Observatory:		 SDO
-        Instrument:		 AIA 3
-        Detector:		 AIA
-        Measurement:		 171.0 Angstrom
-        Wavelength:		 171.0 Angstrom
-        Observation Date:	 2011-06-07 06:33:02
-        Exposure Time:		 0.234256 s
-        Dimension:		 [4. 4.] pix
-        Coordinate System:	 helioprojective
-        Scale:			 [2.402792 2.402792] arcsec / pix
-        Reference Pixel:	 [126.5 126.5] pix
-        Reference Coord:	 [3.22309951 1.38578135] arcsec
-        array([[565.81494, 585.0416 , 656.4552 , 670.18854],
-            [516.1865 , 555.7032 , 634.7365 , 661.90424],
-            [620.9256 , 620.9256 , 654.8825 , 596.6707 ],
-            [667.5083 , 560.52094, 651.22766, 530.28534]], dtype=float32)
+        Observatory:         SDO
+        Instrument:          AIA 3
+        Detector:            AIA
+        Measurement:         171.0 Angstrom
+        Wavelength:          171.0 Angstrom
+        Observation Date:    2011-06-07 06:33:02
+        Exposure Time:       0.234256 s
+        Dimension:           [5. 5.] pix
+        Coordinate System:   helioprojective
+        Scale:               [2.402792 2.402792] arcsec / pix
+        Reference Pixel:     [125.5 125.5] pix
+        Reference Coord:     [3.22309951 1.38578135] arcsec
+        ...
 
-        >>> bottom_left_vector = SkyCoord([0, 10]  * u.arcsec, [0, 10] * u.arcsec, frame='heliographic_stonyhurst')
+        >>> bottom_left_vector = SkyCoord([0, 10]  * u.deg, [0, 10] * u.deg, frame='heliographic_stonyhurst')
         >>> aia.submap(bottom_left_vector)   # doctest: +REMOTE_DATA
         <sunpy.map.sources.sdo.AIAMap object at 0x7f91aece8be0>
         SunPy Map
         ---------
-        Observatory:		 SDO
-        Instrument:		 AIA 3
-        Detector:		 AIA
-        Measurement:		 171.0 Angstrom
-        Wavelength:		 171.0 Angstrom
-        Observation Date:	 2011-06-07 06:33:02
-        Exposure Time:		 0.234256 s
-        Dimension:		 [4. 5.] pix
-        Coordinate System:	 helioprojective
-        Scale:			 [2.402792 2.402792] arcsec / pix
-        Reference Pixel:	 [1.5 1.5] pix
-        Reference Coord:	 [3.22309951 1.38578135] arcsec
-        array([[213.9748 , 256.76974, 244.54262, 356.62466],
-            [223.74321, 258.0102 , 292.27716, 340.65408],
-            [219.53459, 242.31648, 308.5911 , 331.373  ],
-            [268.24377, 254.83157, 268.24377, 321.89252],
-            [249.99167, 265.14267, 274.61206, 240.5223 ]], dtype=float32)
+        Observatory:         SDO
+        Instrument:          AIA 3
+        Detector:            AIA
+        Measurement:         171.0 Angstrom
+        Wavelength:          171.0 Angstrom
+        Observation Date:    2011-06-07 06:33:02
+        Exposure Time:       0.234256 s
+        Dimension:           [70. 69.] pix
+        Coordinate System:   helioprojective
+        Scale:               [2.402792 2.402792] arcsec / pix
+        Reference Pixel:     [1.5 0.5] pix
+        Reference Coord:     [3.22309951 1.38578135] arcsec
+        ...
         """
         # Check that we have been given a valid combination of inputs
         # [False, False, False] is valid if bottom_left contains the two corner coords
@@ -1527,54 +1557,47 @@ class GenericMap(NDData):
                 not in [[True, False, False], [False, False, False], [False, True, True]]):
             raise ValueError("Either top_right alone or both width and height must be specified.")
         # parse input arguments
-        bottom_left, top_right = self._parse_submap_input(bottom_left, top_right, width, height)
+        pixel_corners = u.Quantity(self._parse_submap_input(bottom_left, top_right, width, height)).T
 
-        x_pixels = u.Quantity([bottom_left[0], top_right[0]]).to_value(u.pix)
-        y_pixels = u.Quantity([bottom_left[1], top_right[1]]).to_value(u.pix)
-        if x_pixels[0] > x_pixels[1]:
-            warnings.warn("The rectangle is inverted in the left/right direction,  "
-                          "which may lead to unintended behavior.", SunpyUserWarning)
-
-        if y_pixels[0] > y_pixels[1]:
-            warnings.warn("The rectangle is inverted in the bottom/top direction, "
-                          "which may lead to unintended behavior.", SunpyUserWarning)
-        # Sort the pixel values so we always slice in the correct direction
-        x_pixels.sort()
-        y_pixels.sort()
+        # The pixel corners result is in Cartesian order, so the first index is
+        # columns and the second is rows.
+        bottom = np.min(pixel_corners[1]).to_value(u.pix)
+        top = np.max(pixel_corners[1]).to_value(u.pix)
+        left = np.min(pixel_corners[0]).to_value(u.pix)
+        right = np.max(pixel_corners[0]).to_value(u.pix)
 
         # Round the lower left pixel to the nearest integer
         # We want 0.5 to be rounded up to 1, so use floor(x + 0.5)
-        x_pixels[0] = np.floor(x_pixels[0] + 0.5)
-        y_pixels[0] = np.floor(y_pixels[0] + 0.5)
+        bottom = np.floor(bottom + 0.5)
+        left = np.floor(left + 0.5)
+
         # Round the top right pixel to the nearest integer, then add 1 for array indexing
         # We want e.g. 2.5 to be rounded down to 2, so use ceil(x - 0.5)
-        x_pixels[1] = np.ceil(x_pixels[1] - 0.5) + 1
-        y_pixels[1] = np.ceil(y_pixels[1] - 0.5) + 1
-
-        x_pixels = np.array(x_pixels)
-        y_pixels = np.array(y_pixels)
+        top = np.ceil(top - 0.5) + 1
+        right = np.ceil(right - 0.5) + 1
 
         # Clip pixel values to max of array, prevents negative
         # indexing
-        x_pixels = np.clip(x_pixels, 0, self.data.shape[1])
-        y_pixels = np.clip(y_pixels, 0, self.data.shape[0])
+        bottom = int(np.clip(bottom, 0, self.data.shape[0]))
+        top = int(np.clip(top, 0, self.data.shape[0]))
+        left = int(np.clip(left, 0, self.data.shape[1]))
+        right = int(np.clip(right, 0, self.data.shape[1]))
 
+        arr_slice = np.s_[bottom:top, left:right]
         # Get ndarray representation of submap
-        xslice = slice(int(x_pixels[0]), int(x_pixels[1]))
-        yslice = slice(int(y_pixels[0]), int(y_pixels[1]))
-        new_data = self.data[yslice, xslice].copy()
+        new_data = self.data[arr_slice].copy()
 
         # Make a copy of the header with updated centering information
         new_meta = self.meta.copy()
         # Add one to go from zero-based to one-based indexing
-        new_meta['crpix1'] = self.reference_pixel.x.to_value(u.pix) + 1 - x_pixels[0]
-        new_meta['crpix2'] = self.reference_pixel.y.to_value(u.pix) + 1 - y_pixels[0]
+        new_meta['crpix1'] = self.reference_pixel.x.to_value(u.pix) + 1 - left
+        new_meta['crpix2'] = self.reference_pixel.y.to_value(u.pix) + 1 - bottom
         new_meta['naxis1'] = new_data.shape[1]
         new_meta['naxis2'] = new_data.shape[0]
 
         # Create new map instance
         if self.mask is not None:
-            new_mask = self.mask[yslice, xslice].copy()
+            new_mask = self.mask[arr_slice].copy()
             # Create new map with the modification
             new_map = self._new_instance(new_data, new_meta, self.plot_settings, mask=new_mask)
             return new_map
@@ -1611,7 +1634,10 @@ class GenericMap(NDData):
                                 "must be a Quantity in units of pixels.")
             # Add width and height to get top_right
             top_right = u.Quantity([bottom_left[0] + width, bottom_left[1] + height])
-        return bottom_left, top_right
+
+        top_left = u.Quantity([top_right[0], bottom_left[1]])
+        bottom_right = u.Quantity([bottom_left[0], top_right[1]])
+        return bottom_left, top_left, top_right, bottom_right
 
     @_parse_submap_input.register(SkyCoord)
     def _parse_submap_coord_input(self, bottom_left, top_right, width, height):
@@ -1620,10 +1646,14 @@ class GenericMap(NDData):
                                                            top_right=top_right,
                                                            width=width,
                                                            height=height)
-        # Convert cordinates to pixels
-        bottom_left = self.world_to_pixel(bottom_left)
-        top_right = self.world_to_pixel(top_right)
-        return bottom_left, top_right
+        frame = bottom_left.frame
+        left_lon, bottom_lat = self._get_lon_lat(bottom_left)
+        right_lon, top_lat = self._get_lon_lat(top_right)
+        corners = SkyCoord([left_lon, left_lon, right_lon, right_lon],
+                           [bottom_lat, top_lat, top_lat, bottom_lat],
+                           frame=frame)
+
+        return tuple(u.Quantity(self.wcs.world_to_pixel(corners), u.pix).T)
 
     @u.quantity_input
     def superpixel(self, dimensions: u.pixel, offset: u.pixel = (0, 0)*u.pixel, func=np.sum):
@@ -1640,7 +1670,8 @@ class GenericMap(NDData):
         offset : tuple
             Offset from (0,0) in original map pixels used to calculate where
             the data used to make the resulting superpixel map starts.
-        func : function applied to the original data
+        func :
+            Function applied to the original data.
             The function 'func' must take a numpy array as its first argument,
             and support the axis keyword with the meaning of a numpy axis
             keyword (see the description of `~numpy.sum` for an example.)
@@ -1753,7 +1784,7 @@ class GenericMap(NDData):
 
         Returns
         -------
-        overlay: `~astropy.visualization.wcsaxes.coordinates_map.CoordinatesMap`
+        overlay: `~astropy.visualization.wcsaxes.CoordinatesMap`
             The wcsaxes coordinate overlay instance.
 
         Notes
@@ -1908,7 +1939,7 @@ class GenericMap(NDData):
         Returns
         -------
         cs : `list`
-            The `~matplotlib.QuadContourSet` object, after it has been added to
+            The `~matplotlib.contour.QuadContourSet` object, after it has been added to
             ``axes``.
 
         Notes
@@ -2035,6 +2066,7 @@ class GenericMap(NDData):
 
         # Normal plot
         plot_settings = copy.deepcopy(self.plot_settings)
+
         if 'title' in plot_settings:
             plot_settings_title = plot_settings.pop('title')
         else:
