@@ -1,25 +1,16 @@
 """SOHO Map subclass definitions"""
 
-import matplotlib.pyplot as plt
 import numpy as np
 from matplotlib import colors
 
 import astropy.units as u
-from astropy.coordinates import CartesianRepresentation, SkyCoord
+from astropy.coordinates import CartesianRepresentation, HeliocentricMeanEcliptic
 from astropy.visualization import PowerStretch
 from astropy.visualization.mpl_normalize import ImageNormalize
 
 from sunpy.map import GenericMap
 from sunpy.map.sources.source_type import source_stretch
 
-# Versions of Astropy that do not have HeliocentricMeanEcliptic have the same frame
-# with the misleading name HeliocentricTrueEcliptic
-try:
-    from astropy.coordinates import HeliocentricMeanEcliptic
-except ImportError:
-    from astropy.coordinates import HeliocentricTrueEcliptic as HeliocentricMeanEcliptic
-
-
 __all__ = ['EITMap', 'LASCOMap', 'MDIMap']
 
 
@@ -50,9 +41,9 @@ class EITMap(GenericMap):
         super().__init__(data, header, **kwargs)
 
         self._nickname = self.detector
-        self.plot_settings['cmap'] = plt.get_cmap(self._get_cmap_name())
+        self.plot_settings['cmap'] = self._get_cmap_name()
         self.plot_settings['norm'] = ImageNormalize(
-            stretch=source_stretch(self.meta, PowerStretch(0.5)))
+            stretch=source_stretch(self.meta, PowerStretch(0.5)), clip=False)
 
     @property
     def detector(self):
@@ -77,7 +68,7 @@ class EITMap(GenericMap):
                                                'unit': u.km,
                                                'representation_type': CartesianRepresentation,
                                                'frame': HeliocentricMeanEcliptic})
-        ] + super()._supported_observer_coordinates
+                ] + super()._supported_observer_coordinates
 
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
@@ -127,9 +118,9 @@ class LASCOMap(GenericMap):
         if 'date_obs' in self.meta:
             self.meta['date_obs'] = self.meta['date-obs']
         self._nickname = self.instrument + "-" + self.detector
-        self.plot_settings['cmap'] = plt.get_cmap('soholasco{det!s}'.format(det=self.detector[1]))
+        self.plot_settings['cmap'] = 'soholasco{det!s}'.format(det=self.detector[1])
         self.plot_settings['norm'] = ImageNormalize(
-            stretch=source_stretch(self.meta, PowerStretch(0.5)))
+            stretch=source_stretch(self.meta, PowerStretch(0.5)), clip=False)
 
     @property
     def measurement(self):
@@ -192,7 +183,7 @@ class MDIMap(GenericMap):
                                                     'radius': self.meta.get('obs_dist'),
                                                     'unit': (u.deg, u.deg, u.AU),
                                                     'frame': "heliographic_carrington"}),
-        ] + super()._supported_observer_coordinates
+                ] + super()._supported_observer_coordinates
 
     @property
     def detector(self):
