@@ -9,9 +9,9 @@ import pytest
 
 import astropy.units as u
 
-from sunpy.map.sources.mlso import KCorMap
-from sunpy.map import Map
 import sunpy.data.test
+from sunpy.map import Map
+from sunpy.map.sources.mlso import KCorMap
 
 path = sunpy.data.test.rootdir
 fitspath = glob.glob(os.path.join(path, "20181209_180305_kcor_l1.5_rebinned.fits"))
@@ -19,7 +19,6 @@ fitspath = glob.glob(os.path.join(path, "20181209_180305_kcor_l1.5_rebinned.fits
 
 @pytest.fixture()
 def kcor():
-
     """Creates an KCorMap from a FITS file."""
     return Map(fitspath)
 
@@ -45,3 +44,8 @@ def test_measurement(kcor):
 def test_observatory(kcor):
     """Tests the observatory property of the KCorMap object."""
     assert kcor.observatory == "MLSO"
+
+
+def test_norm_clip(kcor):
+    # Tests that the default normalizer has clipping disabled
+    assert not kcor.plot_settings['norm'].clip
