@@ -2,9 +2,9 @@ import os
 
 import pytest
 
-from sunpy.map.sources.trace import TRACEMap
-from sunpy.map import Map
 import sunpy.data.test
+from sunpy.map import Map
+from sunpy.map.sources.trace import TRACEMap
 
 path = sunpy.data.test.rootdir
 fitspath = os.path.join(path, "tsi20010130_025823_a2.fits")
@@ -37,3 +37,8 @@ def test_measurement(createTRACE):
 def test_observatory(createTRACE):
     """Tests the observatory property of the TRACEMap object."""
     assert createTRACE.observatory == "TRACE"
+
+
+def test_norm_clip(createTRACE):
+    # Tests that the default normalizer has clipping disabled
+    assert not createTRACE.plot_settings['norm'].clip
