@@ -30,6 +30,11 @@ from sunpy.util import SunpyDeprecationWarning, SunpyUserWarning
 testpath = sunpy.data.test.rootdir
 
 
+@pytest.fixture
+def test_map(request):
+    return request.getfixturevalue(request.param)
+
+
 @pytest.fixture
 def hmi_test_map():
     return sunpy.map.Map(os.path.join(testpath, "resampled_hmi.fits"))
@@ -45,6 +50,11 @@ def aia171_test_map():
     return sunpy.map.Map((map.data, header))
 
 
+@pytest.fixture
+def aia171_roll_map(aia171_test_map):
+    return aia171_test_map.rotate(-45*u.deg)
+
+
 @pytest.fixture
 def heliographic_test_map():
     map = sunpy.map.Map(os.path.join(testpath, 'heliographic_phase_map.fits.gz'))
@@ -76,6 +86,8 @@ def generic_map():
         'CDELT2': 10,
         'CUNIT1': 'arcsec',
         'CUNIT2': 'arcsec',
+        'CTYPE1': 'HPLN-TAN',
+        'CTYPE2': 'HPLT-TAN',
         'PC1_1': 0,
         'PC1_2': -1,
         'PC2_1': 1,
@@ -210,7 +222,7 @@ def test_rsun_obs(generic_map):
 
 
 def test_coordinate_system(generic_map):
-    assert generic_map.coordinate_system == ('HPLN-   ', 'HPLT-   ')
+    assert generic_map.coordinate_system == ('HPLN-TAN', 'HPLT-TAN')
 
 
 def test_carrington_longitude(generic_map):
@@ -348,6 +360,34 @@ def test_world_to_pixel_error(generic_map):
         generic_map.world_to_pixel(1)
 
 
+@pytest.mark.parametrize('origin', [0, 1])
+def test_world_pixel_roundtrip(simple_map, origin):
+    pix = 1 * u.pix, 1 * u.pix
+    coord = simple_map.pixel_to_world(*pix, origin=origin)
+    pix_roundtrip = simple_map.world_to_pixel(coord, origin=origin)
+
+    assert u.allclose(pix_roundtrip.x, pix[0], atol=1e-10 * u.pix)
+    assert u.allclose(pix_roundtrip.y, pix[1], atol=1e-10 * u.pix)
+
+
+def test_swapped_ctypes(simple_map):
+    # Check that CTYPES different from normal work fine
+    simple_map.meta['ctype1'] = 'HPLT-TAN'   # Usually HPLN
+    simple_map.meta['ctype2'] = 'HPLN-TAN'   # Usually HPLT
+    assert u.allclose(simple_map.bottom_left_coord.Tx, -1 * u.arcsec)
+    assert u.allclose(simple_map.bottom_left_coord.Ty, -2 * u.arcsec)
+    assert u.allclose(simple_map.top_right_coord.Tx, 1 * u.arcsec)
+    assert u.allclose(simple_map.top_right_coord.Ty, 2 * u.arcsec)
+
+    # Put them back
+    simple_map.meta['ctype1'] = 'HPLN-TAN'   # Usually HPLN
+    simple_map.meta['ctype2'] = 'HPLT-TAN'   # Usually HPLT
+    assert u.allclose(simple_map.bottom_left_coord.Tx, -2 * u.arcsec)
+    assert u.allclose(simple_map.bottom_left_coord.Ty, -1 * u.arcsec)
+    assert u.allclose(simple_map.top_right_coord.Tx, 2 * u.arcsec)
+    assert u.allclose(simple_map.top_right_coord.Ty, 1 * u.arcsec)
+
+
 def test_save(aia171_test_map, generic_map):
     """Tests the map save function"""
     aiamap = aia171_test_map
@@ -502,7 +542,50 @@ def test_submap_world(simple_map, rect, submap_out):
         np.testing.assert_equal(submap.data, submap_out)
 
 
-# Check that submap works with units convertable to pix but that aren't pix
+@pytest.mark.parametrize('test_map', ("aia171_roll_map", "aia171_test_map",
+                                      "hmi_test_map", "aia171_test_map_with_mask"),
+                         indirect=['test_map'])
+def test_submap_world_corners(test_map):
+    """
+    This test checks that when an unaligned map is cropped with submap that the
+    resulting map contains all four corners of the input world coordinate
+    bounding box.
+    """
+    corners = SkyCoord(Tx=[300, 300, 800, 800], Ty=[0, 500, 500, 0],
+                       unit=u.arcsec, frame=test_map.coordinate_frame)
+
+    submap = test_map.submap(corners[0], top_right=corners[2])
+
+    pix_corners = np.array(submap.wcs.world_to_pixel(corners)).T
+    for pix_corner in pix_corners:
+        assert ((-0.5, -0.5) <= pix_corner).all()
+        assert (pix_corner <= submap.data.shape[::-1]).all()
+
+    if test_map.mask is not None:
+        assert submap.mask.shape == submap.data.shape
+
+
+@pytest.mark.parametrize('test_map', ("aia171_test_map", "heliographic_test_map"),
+                         indirect=['test_map'])
+def test_submap_hgs_corners(test_map):
+    """
+    This test checks that when an unaligned map is cropped with submap that the
+    resulting map contains all four corners of the input world coordinate
+    bounding box.
+    """
+    corners = SkyCoord([10, 10, 40, 40], [-10, 30, 30, -10],
+                       unit=u.deg, frame="heliographic_stonyhurst",
+                       obstime=test_map.date)
+
+    submap = test_map.submap(corners[0], top_right=corners[2])
+
+    pix_corners = np.array(submap.wcs.world_to_pixel(corners)).T
+    for pix_corner in pix_corners:
+        assert ((-0.5, -0.5) <= pix_corner).all()
+        assert (pix_corner <= submap.data.shape[::-1]).all()
+
+
+# Check that submap works with units convertible to pix but that aren't pix
 @pytest.mark.parametrize('unit', [u.pix, u.mpix * 1e3])
 def test_submap_data_header(generic_map, unit):
     """Check data and header information for a submap"""
@@ -758,8 +841,8 @@ def test_as_mpl_axes_aia171(aia171_test_map):
 def test_pixel_to_world_no_projection(generic_map):
     with pytest.warns(SunpyUserWarning, match='Missing metadata for observer'):
         out = generic_map.pixel_to_world(*u.Quantity(generic_map.reference_pixel))
-    assert_quantity_allclose(out.Tx, 0*u.arcsec)
-    assert_quantity_allclose(out.Ty, 0*u.arcsec)
+    assert_quantity_allclose(out.Tx, 0*u.arcsec, atol=1e-26*u.arcsec)
+    assert_quantity_allclose(out.Ty, 0*u.arcsec, atol=1e-26*u.arcsec)
 
 
 def test_validate_meta(generic_map):
