@@ -1,15 +1,18 @@
-# -*- coding: utf-8 -*-
 """
 Test mapsequence functionality
 """
+import os
+from unittest import mock
+
 import numpy as np
+import pytest
+
 import astropy.units as u
+
 import sunpy
+import sunpy.data.test
 import sunpy.map
 from sunpy.util.metadata import MetaDict
-import pytest
-import os
-import sunpy.data.test
 
 
 @pytest.fixture
@@ -22,6 +25,16 @@ def aia_map():
     return sunpy.map.Map(aia_file)
 
 
+@pytest.fixture
+def eit_map():
+    """
+    Load SunPy's test EIT image.
+    """
+    testpath = sunpy.data.test.rootdir
+    eit_file = os.path.join(testpath, "EIT", "efz20040301.020010_s.fits")
+    return sunpy.map.Map(eit_file)
+
+
 @pytest.fixture
 def masked_aia_map(aia_map):
     """
@@ -42,6 +55,14 @@ def mapsequence_all_the_same(aia_map):
     return sunpy.map.Map([aia_map, aia_map], sequence=True)
 
 
+@pytest.fixture
+def mapsequence_different_maps(aia_map, eit_map):
+    """
+    Simple `sunpy.map.mapsequence` for testing, in which there are different maps
+    """
+    return sunpy.map.Map([aia_map, eit_map], sequence=True)
+
+
 @pytest.fixture
 def mapsequence_all_the_same_all_have_masks(masked_aia_map):
     """ Simple `sunpy.map.mapsequence` for testing, in which all the maps have
@@ -60,7 +81,7 @@ def mapsequence_all_the_same_some_have_masks(aia_map, masked_aia_map):
 def mapsequence_different(aia_map):
     """ Mapsequence allows that the size of the image data in each map be
     different.  This mapsequence contains such maps."""
-    return sunpy.map.Map([aia_map, aia_map.superpixel((4, 4)*u.pix)], sequence=True)
+    return sunpy.map.Map([aia_map, aia_map.superpixel((4, 4) * u.pix)], sequence=True)
 
 
 def test_all_maps_same_shape(mapsequence_all_the_same, mapsequence_different):
@@ -144,4 +165,54 @@ def test_all_meta(mapsequence_all_the_same):
     meta = mapsequence_all_the_same.all_meta()
     assert len(meta) == 2
     assert np.all(np.asarray([isinstance(h, MetaDict) for h in meta]))
-    assert np.all(np.asarray([meta[i] == mapsequence_all_the_same[i].meta for i in range(0, len(meta))]))
+    assert np.all(np.asarray(
+        [meta[i] == mapsequence_all_the_same[i].meta for i in range(0, len(meta))]))
+
+
+def test_repr(mapsequence_all_the_same, mapsequence_different_maps):
+    """
+    Tests that overidden __repr__ functionality works as expected. Test
+    for mapsequence of same maps as well that of different maps.
+    """
+    # Test the case of MapSequence having same maps
+    expected_out = f'MapSequence of 2 elements, with maps from AIAMap'
+    obtained_out = repr(mapsequence_all_the_same)
+    assert obtained_out.startswith(object.__repr__(mapsequence_all_the_same))
+    assert len(mapsequence_all_the_same) == 2
+    assert expected_out in obtained_out
+
+    # Test the case of MapSequence having different maps
+    expected_out1 = f'MapSequence of 2 elements, with maps from AIAMap, EITMap'
+    expected_out2 = f'MapSequence of 2 elements, with maps from EITMap, AIAMap'
+    obtained_out = repr(mapsequence_different_maps)
+    assert obtained_out.startswith(object.__repr__(mapsequence_different_maps))
+    assert len(mapsequence_different_maps) == 2
+    assert expected_out1 in obtained_out or expected_out2 in obtained_out
+
+
+def test_derotate():
+    with pytest.raises(NotImplementedError):
+        mapsequence = sunpy.map.MapSequence(derotate=True)
+
+
+def test_repr_html(mapsequence_all_the_same):
+    html_string = mapsequence_all_the_same._repr_html_()
+    for m in mapsequence_all_the_same.maps:
+        assert m._repr_html_() in html_string
+
+
+def test_quicklook(mapsequence_all_the_same):
+    with mock.patch('webbrowser.open_new_tab') as mockwbopen:
+        mapsequence_all_the_same.quicklook()
+
+    # Check that the mock web browser was opened with a file URL
+    mockwbopen.assert_called_once()
+    file_url = mockwbopen.call_args[0][0]
+    assert file_url.startswith('file://')
+
+    # Open the file specified in the URL and confirm that it contains the HTML
+    with open(file_url[7:], 'r') as f:
+        html_string = f.read()
+
+        for m in mapsequence_all_the_same.maps:
+            assert m._repr_html_() in html_string
