@@ -9,12 +9,15 @@ from astropy.coordinates import BaseCoordinateFrame, SkyCoord
 import sunpy.data.test
 import sunpy.map
 from sunpy.coordinates import HeliographicStonyhurst
+from sunpy.coordinates.frames import HeliographicCarrington
 from sunpy.coordinates.utils import GreatArc
 from sunpy.map.maputils import (
+    _verify_coordinate_helioprojective,
     all_coordinates_from_map,
     all_pixel_indices_from_map,
     contains_full_disk,
     contains_limb,
+    contains_solar_center,
     coordinate_is_on_solar_disk,
     is_all_off_disk,
     is_all_on_disk,
@@ -52,6 +55,24 @@ def sub_smap(aia171_test_map):
     return aia171_test_map.submap((0, 0)*u.pix, top_right=(50, 60)*u.pix)
 
 
+@pytest.fixture
+def non_helioprojective_map():
+    data = np.arange(0, 100).reshape(10, 10)
+    coord = SkyCoord(0*u.arcsec, 0*u.arcsec, obstime='2013-10-28 08:24',
+                     observer='earth', frame=HeliographicCarrington)
+    header = sunpy.map.header_helper.make_fitswcs_header(data, coord,
+                                                         reference_pixel=[0, 0]*u.pixel,
+                                                         scale=[2, 2]*u.arcsec/u.pixel,
+                                                         telescope='Fake Telescope', instrument='UV detector',
+                                                         wavelength=1000*u.angstrom)
+    return sunpy.map.Map(data, header)
+
+
+@pytest.fixture
+def non_helioprojective_skycoord():
+    return SkyCoord(0 * u.rad, 0 * u.rad, frame="icrs")
+
+
 @pytest.fixture
 def aia_test_arc(aia171_test_map):
     start = SkyCoord(735 * u.arcsec, -471 * u.arcsec, frame=aia171_test_map.coordinate_frame)
@@ -175,3 +196,46 @@ def test_data_at_coordinates(aia171_test_map, aia_test_arc):
     intensity_along_arc = aia171_test_map.data[y, x]
     np.testing.assert_almost_equal(data[0], intensity_along_arc[0], decimal=1)
     np.testing.assert_almost_equal(data[-1], intensity_along_arc[-1], decimal=1)
+
+
+def test_contains_solar_center(aia171_test_map, all_off_disk_map, all_on_disk_map, straddles_limb_map, sub_smap):
+    assert contains_solar_center(aia171_test_map)
+    assert not contains_solar_center(all_off_disk_map)
+    assert not contains_solar_center(all_on_disk_map)
+    assert not contains_solar_center(straddles_limb_map)
+    assert not contains_solar_center(sub_smap)
+
+
+def test_verify_coordinate_helioprojective(aia171_test_map, all_off_disk_map, all_on_disk_map, straddles_limb_map,
+                                           sub_smap, non_helioprojective_map, non_helioprojective_skycoord):
+    # These should be helioprojective.
+    _verify_coordinate_helioprojective(aia171_test_map.coordinate_frame)
+    _verify_coordinate_helioprojective(all_off_disk_map.coordinate_frame)
+    _verify_coordinate_helioprojective(all_on_disk_map.coordinate_frame)
+    _verify_coordinate_helioprojective(straddles_limb_map.coordinate_frame)
+    _verify_coordinate_helioprojective(sub_smap.coordinate_frame)
+    # These are not.
+    with pytest.raises(ValueError, match=r"HeliographicCarrington, .* Helioprojective"):
+        _verify_coordinate_helioprojective(non_helioprojective_map.coordinate_frame)
+    with pytest.raises(ValueError, match=r"ICRS, .* Helioprojective"):
+        _verify_coordinate_helioprojective(non_helioprojective_skycoord)
+
+
+def test_functions_raise_non_frame_coords(non_helioprojective_skycoord):
+    with pytest.raises(ValueError, match=r"ICRS, .* Helioprojective"):
+        solar_angular_radius(non_helioprojective_skycoord)
+    with pytest.raises(ValueError, match=r"ICRS, .* Helioprojective"):
+        coordinate_is_on_solar_disk(non_helioprojective_skycoord)
+
+
+def test_functions_raise_non_frame_map(non_helioprojective_map):
+    with pytest.raises(ValueError, match=r"HeliographicCarrington, .* Helioprojective"):
+        contains_full_disk(non_helioprojective_map)
+    with pytest.raises(ValueError, match=r"HeliographicCarrington, .* Helioprojective"):
+        contains_solar_center(non_helioprojective_map)
+    with pytest.raises(ValueError, match=r"HeliographicCarrington, .* Helioprojective"):
+        is_all_off_disk(non_helioprojective_map)
+    with pytest.raises(ValueError, match=r"HeliographicCarrington, .* Helioprojective"):
+        contains_limb(non_helioprojective_map)
+    with pytest.raises(ValueError, match=r"HeliographicCarrington, .* Helioprojective"):
+        on_disk_bounding_coordinates(non_helioprojective_map)
