@@ -1,23 +1,25 @@
-# -*- coding: utf-8 -*-
 """
 Test Generic Map
 """
 import os
-import pytest
 
+import matplotlib.pyplot as plt
 import numpy as np
+import pytest
 
 import astropy.units as u
 from astropy.coordinates import SkyCoord
-import matplotlib.pyplot as plt
 
 import sunpy
-import sunpy.map
 import sunpy.coordinates
 import sunpy.data.test
+import sunpy.map
+from sunpy.coordinates.utils import get_rectangle_coordinates
 from sunpy.tests.helpers import figure_test
+from sunpy.util.exceptions import SunpyUserWarning
 
 testpath = sunpy.data.test.rootdir
+pytestmark = pytest.mark.filterwarnings('ignore:Missing metadata')
 
 
 @pytest.fixture
@@ -37,7 +39,7 @@ def aia171_test_map_with_mask(aia171_test_map):
     mask[0:shape[0] // 2, 0:shape[1] // 2] = True
     return sunpy.map.Map(np.ma.array(
         aia171_test_map.data, mask=mask),
-                         aia171_test_map.meta)
+        aia171_test_map.meta)
 
 
 @figure_test
@@ -45,6 +47,22 @@ def test_plot_aia171(aia171_test_map):
     aia171_test_map.plot()
 
 
+@figure_test
+def test_plot_rotated_aia171(aia171_test_map):
+    # Check that plotting a rotated map and a rectangle works as expected
+
+    # Set rotation metadata
+    aia171_test_map.meta['CROTA2'] = 45
+    # Plot map
+    aia171_test_map.plot()
+    # Plot rectangle
+    bottom_left = SkyCoord(
+        0 * u.arcsec, 0 * u.arcsec, frame=aia171_test_map.coordinate_frame)
+    w = 100 * u.arcsec
+    h = 200 * u.arcsec
+    aia171_test_map.draw_rectangle(bottom_left, width=w, height=h)
+
+
 @figure_test
 def test_plot_aia171_clip(aia171_test_map):
     aia171_test_map.plot(clip_interval=(5., 99.)*u.percent)
@@ -84,17 +102,29 @@ def test_peek_grid_limb_aia171(aia171_test_map):
 @figure_test
 def test_plot_aia171_nowcsaxes(aia171_test_map):
     ax = plt.gca()
-    aia171_test_map.plot(axes=ax)
+    with pytest.warns(SunpyUserWarning, match='WCSAxes not being used as the axes'):
+        aia171_test_map.plot(axes=ax)
 
 
 @figure_test
-def test_rectangle_aia171(aia171_test_map):
+def test_rectangle_aia171_width_height(aia171_test_map):
     aia171_test_map.plot()
     bottom_left = SkyCoord(
         0 * u.arcsec, 0 * u.arcsec, frame=aia171_test_map.coordinate_frame)
     w = 100 * u.arcsec
     h = 100 * u.arcsec
-    aia171_test_map.draw_rectangle(bottom_left, w, h)
+    aia171_test_map.draw_rectangle(bottom_left, width=w, height=h)
+
+
+@figure_test
+def test_rectangle_aia171_top_right(aia171_test_map):
+    aia171_test_map.plot()
+    bottom_left = SkyCoord(
+        0 * u.arcsec, 0 * u.arcsec, frame=aia171_test_map.coordinate_frame)
+    w = 100 * u.arcsec
+    h = 100 * u.arcsec
+    bottom_left, top_right = get_rectangle_coordinates(bottom_left, width=w, height=h)
+    aia171_test_map.draw_rectangle(bottom_left, top_right=top_right)
 
 
 @figure_test
@@ -105,7 +135,8 @@ def test_plot_masked_aia171(aia171_test_map_with_mask):
 @figure_test
 def test_plot_masked_aia171_nowcsaxes(aia171_test_map_with_mask):
     ax = plt.gca()
-    aia171_test_map_with_mask.plot(axes=ax)
+    with pytest.warns(SunpyUserWarning, match='WCSAxes not being used as the axes'):
+        aia171_test_map_with_mask.plot(axes=ax)
 
 
 @figure_test
@@ -116,8 +147,9 @@ def test_plot_aia171_superpixel(aia171_test_map):
 @figure_test
 def test_plot_aia171_superpixel_nowcsaxes(aia171_test_map):
     ax = plt.gca()
-    aia171_test_map.superpixel(
-        (9, 7) * u.pix, offset=(4, 4) * u.pix).plot(axes=ax)
+    with pytest.warns(SunpyUserWarning, match='WCSAxes not being used as the axes'):
+        aia171_test_map.superpixel(
+            (9, 7) * u.pix, offset=(4, 4) * u.pix).plot(axes=ax)
 
 
 @figure_test
@@ -129,8 +161,9 @@ def test_plot_masked_aia171_superpixel(aia171_test_map_with_mask):
 @figure_test
 def test_plot_masked_aia171_superpixel_nowcsaxes(aia171_test_map_with_mask):
     ax = plt.gca()
-    aia171_test_map_with_mask.superpixel(
-        (9, 7) * u.pix, offset=(4, 4) * u.pix).plot(axes=ax)
+    with pytest.warns(SunpyUserWarning, match='WCSAxes not being used as the axes'):
+        aia171_test_map_with_mask.superpixel(
+            (9, 7) * u.pix, offset=(4, 4) * u.pix).plot(axes=ax)
 
 
 @figure_test
@@ -145,10 +178,27 @@ def test_heliographic_peek(heliographic_test_map):
 
 
 @figure_test
-def test_heliographic_rectangle(heliographic_test_map):
+def test_heliographic_rectangle_width_height(heliographic_test_map):
     heliographic_test_map.plot()
-    bottom = SkyCoord(
+    bottom_left = SkyCoord(
         60 * u.deg, 50 * u.deg, frame=heliographic_test_map.coordinate_frame)
     w = 13 * u.deg
     h = 13 * u.deg
-    heliographic_test_map.draw_rectangle(bottom, w, h, color='cyan')
+    heliographic_test_map.draw_rectangle(bottom_left, width=w, height=h, color='cyan')
+
+
+@figure_test
+def test_heliographic_rectangle_top_right(heliographic_test_map):
+    heliographic_test_map.plot()
+    bottom_left = SkyCoord(
+        60 * u.deg, 50 * u.deg, frame=heliographic_test_map.coordinate_frame)
+    w = 13 * u.deg
+    h = 13 * u.deg
+    bottom_left, top_right = get_rectangle_coordinates(bottom_left, width=w, height=h)
+    heliographic_test_map.draw_rectangle(bottom_left, width=w, height=h, color='cyan')
+
+
+@figure_test
+def test_heliographic_grid_annotations(heliographic_test_map):
+    heliographic_test_map.plot()
+    heliographic_test_map.draw_grid(annotate=False)
