@@ -2,15 +2,13 @@
 # This module was developed under funding by
 # Google Summer of Code 2014
 
-from astropy.time import TimeDelta
 import astropy.units as u
+from astropy.time import TimeDelta
 
+from sunpy.net.dataretriever import GenericClient
 from sunpy.time import TimeRange
 from sunpy.util.scraper import Scraper
 
-from ..client import GenericClient
-
-
 __all__ = ['EVEClient']
 
 BASEURL = ('http://lasp.colorado.edu/eve/data_access/evewebdata/quicklook/'
@@ -19,24 +17,23 @@ BASEURL = ('http://lasp.colorado.edu/eve/data_access/evewebdata/quicklook/'
 
 class EVEClient(GenericClient):
     """
-    Provides access to Level 0C Extreme ultraviolet Variability Experiment (EVE) data
-    as hosted by `LASP <http://lasp.colorado.edu/home/eve/data/data-access/>`_.
+    Provides access to Level 0C Extreme ultraviolet Variability Experiment (EVE) data.
 
     To use this client you must request Level 0 data.
+    It is hosted by `LASP <http://lasp.colorado.edu/home/eve/data/data-access/>`__.
 
     Examples
     --------
 
     >>> from sunpy.net import Fido, attrs as a
     >>> results = Fido.search(a.Time("2016/1/1", "2016/1/2"),
-    ...                       a.Instrument('EVE'), a.Level(0))  #doctest: +REMOTE_DATA
-    >>> results  #doctest: +REMOTE_DATA +ELLIPSIS
+    ...                       a.Instrument.eve, a.Level.zero)  #doctest: +REMOTE_DATA
+    >>> results  #doctest: +REMOTE_DATA
     <sunpy.net.fido_factory.UnifiedResponse object at ...>
     Results from 1 Provider:
     <BLANKLINE>
     2 Results from the EVEClient:
          Start Time           End Time      Source Instrument Wavelength
-           str19               str19         str3     str3       str3
     ------------------- ------------------- ------ ---------- ----------
     2016-01-01 00:00:00 2016-01-02 00:00:00    SDO        eve        nan
     2016-01-02 00:00:00 2016-01-03 00:00:00    SDO        eve        nan
@@ -100,14 +97,41 @@ class EVEClient(GenericClient):
         boolean
             answer as to whether client can service the query
         """
-        chk_var = 0
+        from sunpy.net import attrs as a
+
+        required = {a.Time, a.Instrument, a.Level}
+        # Level should really be in here, but VSO doesn't correctly provide
+        # Level information currently.
+        optional = {}
+        if not cls.check_attr_types_in_query(query, required, optional):
+            return False
+
+        matches = True
         for x in query:
-            if x.__class__.__name__ == 'Instrument' and x.value.lower() == 'eve':
-                chk_var += 1
+            if isinstance(x, a.Instrument) and x.value.lower() != 'eve':
+                matches = False
+            if isinstance(x, a.Level):
+                # Level can be basically anything, this function should never
+                # really error. If level is a string we try and convert it to
+                # an int, if it's the string "0CS" we match it. Otherwise we
+                # check it's equal to 0
+                value = x.value
+                if isinstance(value, str):
+                    if value.lower() == '0cs':
+                        value = 0
+                    else:
+                        try:
+                            value = int(value)
+                        except ValueError:
+                            matches = False
+                if value != 0:
+                    matches = False
 
-            elif x.__class__.__name__ == 'Level' and x.value == 0:
-                chk_var += 1
+        return matches
 
-        if chk_var == 2:
-            return True
-        return False
+    @classmethod
+    def register_values(cls):
+        from sunpy.net import attrs
+        adict = {attrs.Instrument: [('EVE', 'Extreme ultraviolet Variability Experiment, which is part of the NASA Solar Dynamics Observatory mission.')],
+                 attrs.Level: [('0', 'EVE: The specific EVE client can only return Level 0C data. Any other number will use the VSO Client.')]}
+        return adict
