@@ -2,19 +2,17 @@
 # This module was developed under funding provided by
 # Google Summer of Code 2014
 import socket
-import posixpath
 from datetime import datetime
 from urllib.error import URLError
 from urllib.request import urlopen, urlretrieve
 
-from dateutil.rrule import rrule, MONTHLY
+from dateutil.rrule import MONTHLY, rrule
 
 import astropy.units as u
 
-from sunpy.time import TimeRange, parse_time
 from sunpy.instr import rhessi
-
-from ..client import GenericClient
+from sunpy.net.dataretriever import GenericClient
+from sunpy.time import TimeRange, parse_time
 
 __all__ = ['RHESSIClient']
 
@@ -42,22 +40,21 @@ def get_base_url():
 
 class RHESSIClient(GenericClient):
     """
-    Provides access to the RHESSI observing summary time series data
-    from the `archive <https://hesperia.gsfc.nasa.gov/hessidata/>`__ or its mirrors.
+    Provides access to the RHESSI observing summary time series data.
+
+    Uses this `archive <https://hesperia.gsfc.nasa.gov/hessidata/>`__ or its mirrors.
 
     Examples
     --------
-
     >>> from sunpy.net import Fido, attrs as a
     >>> results = Fido.search(a.Time("2016/1/1", "2016/1/2"),
-    ...                       a.Instrument('RHESSI'))  #doctest: +REMOTE_DATA
-    >>> results  #doctest: +REMOTE_DATA +ELLIPSIS
+    ...                       a.Instrument.rhessi, a.Physobs.summary_lightcurve)  #doctest: +REMOTE_DATA
+    >>> results  #doctest: +REMOTE_DATA
     <sunpy.net.fido_factory.UnifiedResponse object at ...>
     Results from 1 Provider:
     <BLANKLINE>
     2 Results from the RHESSIClient:
          Start Time           End Time      Source Instrument Wavelength
-           str19               str19         str6     str6       str3
     ------------------- ------------------- ------ ---------- ----------
     2016-01-01 00:00:00 2016-01-01 23:59:59 rhessi     rhessi        nan
     2016-01-02 00:00:00 2016-01-02 23:59:59 rhessi     rhessi        nan
@@ -110,8 +107,8 @@ class RHESSIClient(GenericClient):
                 d[0:20], 'hsi_obssumm_%Y%m%d') for d in this_month_obssumm_filenames]
             for i, this_date in enumerate(daily_filenames_dates):
                 if dt.start <= this_date <= dt.end:
-                    filenames.append(posixpath.join(get_base_url(), 'metadata',
-                                                    'catalog', this_month_obssumm_filenames[i] + 's'))
+                    filenames.append(
+                        get_base_url()+f'metadata/catalog/{this_month_obssumm_filenames[i]}s')
 
         return filenames
 
@@ -136,7 +133,7 @@ class RHESSIClient(GenericClient):
         Examples
         --------
         >>> from sunpy.net.dataretriever.sources.rhessi import RHESSIClient
-        >>> fname, headers = RHESSIClient.get_observing_summary_dbase_file('2011/04/04')   # doctest: +REMOTE_DATA
+        >>> fname, headers = RHESSIClient.get_observing_summary_dbase_file('2011/04/04')  # doctest: +REMOTE_DATA
 
         References
         ----------
@@ -151,7 +148,7 @@ class RHESSIClient(GenericClient):
         if _time < parse_time("2002/02/01"):
             raise ValueError("RHESSI summary files are not available before 2002-02-01")
 
-        url = posixpath.join(get_base_url(), 'dbase', _time.strftime("hsi_obssumm_filedb_%Y%m.txt"))
+        url = get_base_url() + f'dbase/{_time.strftime("hsi_obssumm_filedb_%Y%m.txt")}'
         return urlretrieve(url)
 
     def _get_url_for_timerange(self, timerange, **kwargs):
@@ -193,9 +190,26 @@ class RHESSIClient(GenericClient):
         boolean
             answer as to whether client can service the query
         """
-        chkattr = ['Time', 'Instrument']
-        chklist = [x.__class__.__name__ in chkattr for x in query]
+        from sunpy.net import attrs as a
+
+        required = {a.Time, a.Instrument}
+        optional = {a.Physobs}
+        if not cls.check_attr_types_in_query(query, required, optional):
+            return False
+
+        matches = True
         for x in query:
-            if x.__class__.__name__ == 'Instrument' and x.value.lower() == 'rhessi':
-                return all(chklist)
-        return False
+            if isinstance(x, a.Instrument) and x.value.lower() != 'rhessi':
+                matches = False
+            if isinstance(x, a.Physobs) and x.value.lower() != 'summary_lightcurve':
+                matches = False
+
+        return matches
+
+    @classmethod
+    def register_values(cls):
+        from sunpy.net import attrs
+        adict = {attrs.Instrument: [('RHESSI',
+                                     'Reuven Ramaty High Energy Solar Spectroscopic Imager.')],
+                 attrs.Physobs: [("summary_lightcurve", "A summary lightcurve.")]}
+        return adict
