@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 This module is meant to parse the HELIO registry and return WSDL endpoints to
 facilitate the interfacing between further modules and HELIO.
@@ -46,7 +45,6 @@ def webservice_parser(service='HEC'):
      'http://festung3.oats.inaf.it:8080/helio-hec/HelioLongQueryService',
      'http://festung1.oats.inaf.it:8080/helio-hec/HelioLongQueryService',
      'http://hec.helio-vo.eu/helio_hec/HelioLongQueryService']
-
     """
     link = RL.LINK + '/' + service.lower()
     xml = link_test(link)
@@ -90,14 +88,14 @@ def endpoint_parser(link):
     --------
     >>> from sunpy.net.helio import parser
     >>> parser.endpoint_parser('http://msslkz.mssl.ucl.ac.uk/helio-hec/HelioService')  # doctest: +REMOTE_DATA
-    ['http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioService?wsdl',
-    'http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioService1_0?wsdl',
-    'http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioService1_0b?wsdl',
-    'http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioLongQueryService?wsdl',
-    'http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioLongQueryService1_0?wsdl',
-    'http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioLongQueryService1_1?wsdl',
-    'http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioLongQueryService1_0b?wsdl',
-    'http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioTavernaService?wsdl']
+    ['http://helio.mssl.ucl.ac.uk/helio-hec/HelioService?wsdl',
+    'http://helio.mssl.ucl.ac.uk/helio-hec/HelioService1_0?wsdl',
+    'http://helio.mssl.ucl.ac.uk/helio-hec/HelioService1_0b?wsdl',
+    'http://helio.mssl.ucl.ac.uk/helio-hec/HelioLongQueryService?wsdl',
+    'http://helio.mssl.ucl.ac.uk/helio-hec/HelioLongQueryService1_0?wsdl',
+    'http://helio.mssl.ucl.ac.uk/helio-hec/HelioLongQueryService1_1?wsdl',
+    'http://helio.mssl.ucl.ac.uk/helio-hec/HelioLongQueryService1_0b?wsdl',
+    'http://helio.mssl.ucl.ac.uk/helio-hec/HelioTavernaService?wsdl']
 
     """
     endpoint_page = link_test(link)
@@ -136,7 +134,7 @@ def taverna_parser(link):
     --------
     >>> from sunpy.net.helio import parser
     >>> parser.taverna_parser('http://msslkz.mssl.ucl.ac.uk/helio-hec/HelioService')  # doctest: +REMOTE_DATA
-    ['http://helio.mssl.ucl.ac.uk:80/helio-hec/HelioTavernaService?wsdl']
+    ['http://helio.mssl.ucl.ac.uk/helio-hec/HelioTavernaService?wsdl']
 
     """
     endpoints = endpoint_parser(link)
@@ -207,7 +205,7 @@ def wsdl_retriever(service='HEC'):
     --------
     >>> from sunpy.net.helio import parser
     >>> parser.wsdl_retriever()  # doctest: +REMOTE_DATA
-    'http://helio.mssl.ucl.ac.uk:80/helio_hec/HelioTavernaService?wsdl'
+    'http://helio.mssl.ucl.ac.uk/helio_hec/HelioTavernaService?wsdl'
 
     Notes
     -----
