@@ -1,5 +1,4 @@
 import os
-import copy
 import pathlib
 from stat import S_IREAD, S_IRGRP, S_IROTH
 from unittest import mock
@@ -12,20 +11,21 @@ from parfive import Results
 from parfive.utils import FailedDownload
 
 import astropy.units as u
+from astropy.table import Table
 
 from sunpy import config
 from sunpy.net import Fido, attr
 from sunpy.net import attrs as a
-from sunpy.net.base_client import BaseClient
+from sunpy.net import jsoc
 from sunpy.net.dataretriever.client import QueryResponse
 from sunpy.net.dataretriever.sources.goes import XRSClient
 from sunpy.net.fido_factory import UnifiedResponse
-from sunpy.net.tests.strategies import goes_time, offline_instruments, online_instruments, time_attr
+from sunpy.net.tests.strategies import goes_time, offline_instruments, online_instruments, srs_time, time_attr
 from sunpy.net.vso import QueryResponse as vsoQueryResponse
 from sunpy.net.vso.vso import DownloadFailed
+from sunpy.tests.helpers import no_vso, skip_windows
 from sunpy.time import TimeRange, parse_time
-from sunpy.util.datatype_factory_base import MultipleMatchError
-from sunpy.tests.helpers import skip_windows
+from sunpy.util.exceptions import SunpyUserWarning
 
 TIMEFORMAT = config.get("general", "time_format")
 
@@ -39,6 +39,8 @@ def offline_query(draw, instrument=offline_instruments()):
     # If we have AttrAnd then we don't have GOES
     if isinstance(query, a.Instrument) and query.value == 'goes':
         query &= draw(goes_time())
+    elif isinstance(query, a.Instrument) and query.value == 'soon':
+        query &= draw(srs_time())
     else:
         query = attr.and_(query, draw(time_attr()))
     return query
@@ -49,13 +51,14 @@ def online_query(draw, instrument=online_instruments()):
     query = draw(instrument)
 
     if isinstance(query, a.Instrument) and query.value == 'eve':
-        query &= a.Level(0)
+        query &= a.Level.zero
     if isinstance(query, a.Instrument) and query.value == 'norh':
         query &= a.Wavelength(17*u.GHz)
 
     return query
 
 
+@no_vso
 @settings(deadline=50000)
 @given(offline_query())
 def test_offline_fido(query):
@@ -67,9 +70,9 @@ def test_offline_fido(query):
 # Until we get more mocked, we can't really do this to online clients.
 # TODO: Hypothesis this again
 @pytest.mark.parametrize("query", [
-    (a.Instrument('eve') & a.Time('2014/7/7', '2014/7/14') & a.Level(0)),
-    (a.Instrument('rhessi') & a.Time('2014/7/7', '2014/7/14')),
-    (a.Instrument('norh') & a.Time('2014/7/7', '2014/7/14') & a.Wavelength(17*u.GHz)),
+    (a.Instrument.eve & a.Time('2014/7/7', '2014/7/14') & a.Level.zero),
+    (a.Instrument.rhessi & a.Time('2014/7/7', '2014/7/14')),
+    (a.Instrument.norh & a.Time('2014/7/7', '2014/7/14') & a.Wavelength(17*u.GHz)),
 ])
 def test_online_fido(query):
     unifiedresp = Fido.search(query)
@@ -99,7 +102,7 @@ def check_response(query, unifiedresp):
 
 @pytest.mark.remote_data
 def test_save_path(tmpdir):
-    qr = Fido.search(a.Instrument('EVE'), a.Time("2016/10/01", "2016/10/02"), a.Level(0))
+    qr = Fido.search(a.Instrument.eve, a.Time("2016/10/01", "2016/10/02"), a.Level.zero)
 
     # Test when path is str
     files = Fido.fetch(qr, path=str(tmpdir / "{instrument}" / "{level}"))
@@ -110,7 +113,7 @@ def test_save_path(tmpdir):
 
 @pytest.mark.remote_data
 def test_save_path_pathlib(tmpdir):
-    qr = Fido.search(a.Instrument('EVE'), a.Time("2016/10/01", "2016/10/02"), a.Level(0))
+    qr = Fido.search(a.Instrument.eve, a.Time("2016/10/01", "2016/10/02"), a.Level.zero)
 
     # Test when path is pathlib.Path
     target_dir = tmpdir.mkdir("down")
@@ -121,6 +124,17 @@ def test_save_path_pathlib(tmpdir):
         assert f"eve{os.path.sep}0" in f
 
 
+@pytest.mark.remote_data
+def test_save_path_cwd(tmpdir):
+    qr = Fido.search(a.Instrument.eve, a.Time("2016/10/01", "2016/10/02"), a.Level.zero)
+
+    # Test when path is ./ for current working directory
+    os.chdir(tmpdir)  # move into temp directory
+    files = Fido.fetch(qr, path="./")
+    for f in files:
+        assert pathlib.Path.cwd().joinpath(f).exists()
+
+
 """
 Factory Tests
 """
@@ -130,33 +144,17 @@ Factory Tests
 def test_unified_response():
     start = parse_time("2012/1/1")
     end = parse_time("2012/1/2")
-    qr = Fido.search(a.Instrument('EVE'), a.Level(0), a.Time(start, end))
+    qr = Fido.search(a.Instrument.eve, a.Level.zero, a.Time(start, end))
     assert qr.file_num == 2
     strings = ['eve', 'SDO', start.strftime(TIMEFORMAT), end.strftime(TIMEFORMAT)]
     assert all(s in qr._repr_html_() for s in strings)
 
 
-def test_no_time_error():
-    # TODO: work out why this is failing sometimes.
-    from sunpy.net import attrs as a
-    query = (a.Instrument('EVE'), a.Level(0))
-    with pytest.raises(ValueError) as excinfo:
-        Fido.search(*query)
-    assert all(str(a) in str(excinfo.value) for a in query)
-
-    query1 = (a.Instrument('EVE') & a.Level(0))
-    query2 = (a.Time("2012/1/1", "2012/1/2") & a.Instrument("AIA"))
-    with pytest.raises(ValueError) as excinfo:
-        Fido.search(query1 | query2)
-    assert all(str(a) in str(excinfo.value) for a in query1.attrs)
-    assert all(str(a) not in str(excinfo.value) for a in query2.attrs)
-
-
 @pytest.mark.remote_data
 def test_no_match():
     with pytest.raises(DrmsQueryError):
         Fido.search(a.Time("2016/10/01", "2016/10/02"), a.jsoc.Series("bob"),
-                    a.vso.Sample(10*u.s))
+                    a.Sample(10*u.s))
 
 
 def test_call_error():
@@ -167,32 +165,11 @@ def test_call_error():
     assert "'UnifiedDownloaderFactory' object is not callable" in str(excinfo.value)
 
 
-@pytest.mark.remote_data
-def test_multiple_match():
-    """
-    Using the builtin clients a multiple match is not possible so we create a
-    dummy class.
-    """
-    new_registry = copy.deepcopy(Fido.registry)
-    Fido.registry = new_registry
-
-    class DummyClient():
-        @classmethod
-        def _can_handle_query(cls, *query):
-            return True
-    Fido.registry.update({DummyClient: DummyClient._can_handle_query})
-
-    with pytest.raises(MultipleMatchError):
-        Fido.search(a.Time("2016/10/1", "2016/10/2"), a.Instrument('lyra'))
-
-    Fido.registry = BaseClient._registry
-
-
 @pytest.mark.remote_data
 def test_fetch():
-    qr = Fido.search(a.Instrument('EVE'),
+    qr = Fido.search(a.Instrument.eve,
                      a.Time("2016/10/01", "2016/10/02"),
-                     a.Level(0))
+                     a.Level.zero)
     res = Fido.fetch(qr)
     assert isinstance(res, Results)
 
@@ -207,7 +184,7 @@ Use LYRA here because it does not use the internet to return results.
 @pytest.mark.remote_data
 def test_unifiedresponse_slicing():
     results = Fido.search(
-        a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
+        a.Time("2012/1/1", "2012/1/5"), a.Instrument.lyra)
     assert isinstance(results[0:2], UnifiedResponse)
     assert isinstance(results[0], UnifiedResponse)
 
@@ -215,14 +192,71 @@ def test_unifiedresponse_slicing():
 @pytest.mark.remote_data
 def test_unifiedresponse_slicing_reverse():
     results = Fido.search(
-        a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
+        a.Time("2012/1/1", "2012/1/5"), a.Instrument.lyra)
     assert isinstance(results[::-1], UnifiedResponse)
     assert len(results[::-1]) == len(results)
     assert isinstance(results[0, ::-1], UnifiedResponse)
-    assert results[0, ::-1]._list[0] == results._list[0][::-1]
+    assert all(results._list[0][::-1].build_table() == results[0, ::-1]._list[0].build_table())
 
 
-def test_vso_unifiedresponse():
+@pytest.mark.remote_data
+def test_tables_single_response():
+    results = Fido.search(
+        a.Time("2012/1/1", "2012/1/5"), a.Instrument.lyra)
+    tables = results.tables
+
+    assert isinstance(tables, list)
+    assert isinstance(tables[0], Table)
+    assert len(tables) == 1
+
+    columns = ['Start Time', 'End Time', 'Source', 'Instrument', 'Wavelength']
+    assert columns == tables[0].colnames
+    assert len(tables[0]) == 5
+
+
+@pytest.mark.remote_data
+def test_tables_multiple_response():
+    results = Fido.search(a.Time('2012/3/4', '2012/3/6'),
+                          a.Instrument.lyra | (a.Instrument.rhessi & a.Physobs.summary_lightcurve))
+    tables = results.tables
+    assert isinstance(tables, list)
+    assert all(isinstance(t, Table) for t in tables)
+    assert len(tables) == 2
+
+    columns = ['Start Time', 'End Time', 'Source', 'Instrument', 'Wavelength']
+    assert columns == tables[0].colnames and columns == tables[1].colnames
+
+    assert all(entry == 'lyra' for entry in tables[0]['Instrument'])
+    assert all(entry == 'rhessi' for entry in tables[1]['Instrument'])
+
+
+@pytest.mark.remote_data
+def test_tables_all_types():
+    # Data retriver response objects
+    drclient = Fido.search(a.Time('2012/3/4', '2012/3/6'),
+                           a.Instrument.lyra | (a.Instrument.rhessi & a.Physobs.summary_lightcurve))
+    drtables = drclient.tables
+    assert isinstance(drtables, list)
+    assert isinstance(drtables[0], Table)
+
+    # VSO response objects
+    vsoclient = Fido.search(a.Time('2011-06-07 06:33', '2011-06-07 06:33:08'),
+                            a.Instrument.aia, a.Wavelength(171 * u.AA))
+    vsotables = vsoclient.tables
+    assert isinstance(vsotables, list)
+    assert isinstance(vsotables[0], Table)
+
+    # JSOC response objects
+    jsocclient = Fido.search(a.Time('2014-01-01T00:00:00', '2014-01-01T01:00:00'),
+                             a.jsoc.Series('hmi.v_45s'), a.jsoc.Notify('sunpy@sunpy.org'))
+    jsoctables = jsocclient.tables
+
+    assert isinstance(jsoctables, list)
+    assert isinstance(jsoctables[0], Table)
+
+
+@mock.patch("sunpy.net.vso.vso.build_client", return_value=True)
+def test_vso_unifiedresponse(mock_build_client):
     vrep = vsoQueryResponse([])
     vrep.client = True
     uresp = UnifiedResponse(vrep)
@@ -232,7 +266,7 @@ def test_vso_unifiedresponse():
 @pytest.mark.remote_data
 def test_responses():
     results = Fido.search(
-        a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
+        a.Time("2012/1/1", "2012/1/5"), a.Instrument.lyra)
 
     for i, resp in enumerate(results.responses):
         assert isinstance(resp, QueryResponse)
@@ -243,12 +277,12 @@ def test_responses():
 @pytest.mark.remote_data
 def test_repr():
     results = Fido.search(
-        a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
+        a.Time("2012/1/1", "2012/1/5"), a.Instrument.lyra)
 
     rep = repr(results)
     rep = rep.split('\n')
     # 6 header lines, the results table and two blank lines at the end
-    assert len(rep) == 7 + len(list(results.responses)[0]) + 2
+    assert len(rep) == 6 + len(list(results.responses)[0]) + 2
 
 
 def filter_queries(queries):
@@ -258,7 +292,7 @@ def filter_queries(queries):
 @pytest.mark.remote_data
 def test_path():
     results = Fido.search(
-        a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
+        a.Time("2012/1/1", "2012/1/5"), a.Instrument.lyra)
 
     Fido.fetch(results, path="notapath/{file}")
 
@@ -267,7 +301,7 @@ def test_path():
 @skip_windows
 def test_path_read_only(tmp_path):
     results = Fido.search(
-        a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
+        a.Time("2012/1/1", "2012/1/5"), a.Instrument.lyra)
 
     # chmod dosen't seem to work correctly on the windows CI
     os.chmod(tmp_path, S_IREAD | S_IRGRP | S_IROTH)
@@ -277,6 +311,7 @@ def test_path_read_only(tmp_path):
             Fido.fetch(results, path=tmp_path / "{file}")
 
 
+@no_vso
 @settings(deadline=50000)
 @given(st.tuples(offline_query(), offline_query()).filter(filter_queries))
 def test_fido_indexing(queries):
@@ -316,6 +351,7 @@ def test_fido_indexing(queries):
         res[1.0132]
 
 
+@no_vso
 @settings(deadline=50000)
 @given(st.tuples(offline_query(), offline_query()).filter(filter_queries))
 def test_fido_iter(queries):
@@ -331,6 +367,7 @@ def test_fido_iter(queries):
         assert isinstance(resp, QueryResponse)
 
 
+@no_vso
 @settings(deadline=50000)
 @given(offline_query())
 def test_repr2(query):
@@ -371,11 +408,15 @@ def test_retry(mock_retry):
 
 
 def results_generator(dl):
-    http = list(dl.http_queue._queue)
-    ftp = list(dl.ftp_queue._queue)
+    http = dl.http_queue
+    ftp = dl.ftp_queue
+    # Handle compatibility with parfive 1.0
+    if not isinstance(dl.http_queue, list):
+        http = list(dl.http_queue._queue)
+        ftp = list(dl.ftp_queue._queue)
 
     outputs = []
-    for url in http+ftp:
+    for url in http + ftp:
         outputs.append(pathlib.Path(url.keywords['url'].split("/")[-1]))
 
     return Results(outputs)
@@ -386,7 +427,7 @@ def results_generator(dl):
             return_value=Results([], errors=[DownloadFailed(None)]))
 @mock.patch("parfive.Downloader.download", new=results_generator)
 def test_vso_errors_with_second_client(mock_download_all):
-    query = a.Time("2011/01/01", "2011/01/02") & (a.Instrument("goes") | a.Instrument("EIT"))
+    query = a.Time("2011/01/01", "2011/01/02") & (a.Instrument.goes | a.Instrument.eit)
 
     qr = Fido.search(query)
 
@@ -414,9 +455,57 @@ def test_mixed_retry_error():
 @mock.patch("sunpy.net.dataretriever.sources.goes.XRSClient.fetch",
             return_value=["hello"])
 def test_client_fetch_wrong_type(mock_fetch):
-    query = a.Time("2011/01/01", "2011/01/02") & a.Instrument("goes")
+    query = a.Time("2011/01/01", "2011/01/02") & a.Instrument.goes
 
     qr = Fido.search(query)
 
     with pytest.raises(TypeError):
         Fido.fetch(qr)
+
+
+@pytest.mark.remote_data
+def test_vso_fetch_hmi(tmpdir):
+    start_time = "2017-01-25"
+    end_time = "2017-01-25T23:59:59"
+    results = Fido.search(a.Time(start_time, end_time),
+                          a.Instrument.hmi & a.Physobs.los_magnetic_field,
+                          a.Sample(1 * u.minute))
+
+    files = Fido.fetch(results[0, 0], path=tmpdir)
+    assert len(files) == 1
+
+
+@pytest.mark.remote_data
+def test_unclosedSocket_warning():
+    with pytest.warns(None):
+        attrs_time = a.Time('2005/01/01 00:10', '2005/01/01 00:15')
+        result = Fido.search(attrs_time, a.Instrument.eit)
+        Fido.fetch(result)
+
+
+def test_fido_no_time(mocker):
+    jsoc_mock = mocker.patch("sunpy.net.jsoc.JSOCClient.search")
+    jsoc_mock.return_value = jsoc.JSOCResponse()
+
+    Fido.search(a.jsoc.Series("test"))
+
+    jsoc_mock.assert_called_once()
+
+
+@pytest.mark.remote_data
+def test_slice_jsoc():
+    tstart = '2011/06/07 06:32:45'
+    tend = '2011/06/07 06:33:15'
+    res = Fido.search(a.Time(tstart, tend), a.jsoc.Series('hmi.M_45s'),
+                      a.jsoc.Notify('jsoc@cadair.com'))
+
+    with pytest.warns(SunpyUserWarning):
+        Fido.fetch(res[0, 0])
+
+    with pytest.warns(SunpyUserWarning):
+        Fido.fetch(res[0, 0:1])
+
+
+def test_fido_repr():
+    output = repr(Fido)
+    assert output[:50] == '<sunpy.net.fido_factory.UnifiedDownloaderFactory o'
