@@ -1,4 +1,4 @@
 # for exposure to from sunpy.net.vso import *
-from sunpy.net.vso.vso import VSOClient, QueryResponse
+from sunpy.net.vso.vso import QueryResponse, VSOClient
 
 __all__ = ['VSOClient', 'QueryResponse']
