@@ -1,36 +1,47 @@
-# -*- coding: utf-8 -*-
 """
 This module provides a wrapper around the VSO API.
 """
 
 import os
 import re
-import sys
+import cgi
+import json
 import socket
+import inspect
+import datetime
 import warnings
 import itertools
 from functools import partial
 from collections import defaultdict
 from urllib.error import URLError, HTTPError
-from urllib.request import urlopen
+from urllib.parse import urlencode
+from urllib.request import Request, urlopen
 
 import zeep
 from zeep.helpers import serialize_object
 
 import astropy.units as u
 from astropy.table import QTable as Table
-from parfive import Downloader, Results
 
-from sunpy import config
-from sunpy.time import TimeRange, parse_time
-from sunpy.net.vso import attrs
+from sunpy import config, log
 from sunpy.net.attr import and_
-from sunpy.util.net import slugify, get_content_disposition
-from sunpy.net.vso.attrs import TIMEFORMAT, walker
-from sunpy.net.base_client import BaseClient
-from sunpy.util.decorators import deprecated
+from sunpy.net.base_client import BaseClient, BaseQueryResponse
+from sunpy.net.vso import attrs
+from sunpy.net.vso.attrs import _walker as walker
+from sunpy.time import TimeRange, parse_time
 from sunpy.util.exceptions import SunpyUserWarning
-
+from sunpy.util.net import slugify
+from sunpy.util.parfive_helpers import Downloader, Results
+from .. import _attrs as core_attrs
+from .exceptions import (
+    DownloadFailed,
+    MissingInformation,
+    MultipleChoices,
+    NoData,
+    UnknownMethod,
+    UnknownStatus,
+    UnknownVersion,
+)
 from .zeep_plugins import SunPyLoggingZeepPlugin
 
 TIME_FORMAT = config.get("general", "time_format")
@@ -43,19 +54,10 @@ DEFAULT_URL_PORT = [{'url': 'http://docs.virtualsolar.org/WSDL/VSOi_rpc_literal.
 RANGE = re.compile(r'(\d+)(\s*-\s*(\d+))?(\s*([a-zA-Z]+))?')
 
 
-# TODO: Name
-class NoData(Exception):
-
-    """ Risen for callbacks of VSOClient that are unable to supply
-    information for the request. """
-    pass
-
-
 class _Str(str):
 
     """ Subclass of string that contains a meta attribute for the
     record_item associated with the file. """
-    pass
 
 
 # ----------------------------------------
@@ -74,11 +76,36 @@ def _parse_date(string):
     return {'time_start': start.strip(), 'time_end': end.strip()}
 
 
-def iter_records(response):
+def iter_sort_response(response):
+    """
+    Sorts the VSO queryresults by their start time.
+
+    Parameters
+    ----------
+    response : `zeep.objects.QueryResponse`
+        A SOAP Object of a VSO queryresult
+
+    Returns
+    -------
+    `list`
+        Sorted record items w.r.t. their start time.
+    """
+    has_time_recs = list()
+    has_notime_recs = list()
     for prov_item in response.provideritem:
         if not hasattr(prov_item, 'record') or not prov_item.record:
             continue
-        yield from prov_item.record.recorditem
+        if not hasattr(prov_item.record, 'recorditem') or not prov_item.record.recorditem:
+            continue
+        rec_item = prov_item.record.recorditem
+        for rec in rec_item:
+            if hasattr(rec, 'time') and hasattr(rec.time, 'start') and rec.time.start is not None:
+                has_time_recs.append(rec)
+            else:
+                has_notime_recs.append(rec)
+    has_time_recs = sorted(has_time_recs, key=lambda x: x.time.start)
+    all_recs = has_time_recs + has_notime_recs
+    return all_recs
 
 
 def iter_errors(response):
@@ -145,28 +172,55 @@ def build_client(url=None, port_name=None, **kwargs):
     return client
 
 
-class QueryResponse(list):
+class QueryResponse(BaseQueryResponse):
     """
     A container for VSO Records returned from VSO Searches.
     """
 
-    def __init__(self, lst, queryresult=None, table=None):
-        super().__init__(lst)
+    def __init__(self, lst, queryresult=None):
+        super().__init__()
+        self._data = lst
         self.queryresult = queryresult
         self.errors = []
-        self.table = None
+        self._client = VSOClient()
+
+    def __getitem__(self, item):
+        # Always index so a list comes back
+        if isinstance(item, int):
+            item = slice(item, item+1)
+        return type(self)(self._data[item], queryresult=self.queryresult)
+
+    def __len__(self):
+        return len(self._data)
+
+    def __iter__(self):
+        for block in self._data:
+            yield block
+
+    @property
+    def blocks(self):
+        return self._data
+
+    @property
+    def client(self):
+        return self._client
+
+    @client.setter
+    def client(self, client):
+        self._client = client
 
     def search(self, *query):
         """ Furtherly reduce the query response by matching it against
         another query, e.g. response.search(attrs.Instrument('aia')). """
         query = and_(*query)
         return QueryResponse(
-            attrs.filter_results(query, self), self.queryresult
+            attrs._filter_results(query, self), self.queryresult
         )
 
     @classmethod
     def create(cls, queryresult):
-        return cls(iter_records(queryresult), queryresult)
+        res = list(iter_sort_response(queryresult))
+        return cls(res, queryresult)
 
     def total_size(self):
         """ Total size of data in KB. May be less than the actual
@@ -244,55 +298,23 @@ class QueryResponse(list):
 
         Returns
         -------
-        s : list
+        s : `set`
             List of strings, containing attribute names in the response blocks.
         """
         s = {a if not a.startswith('_') else None for a in dir(self[0])}
         for resp in self[1:]:
+            if len(s) == 0:
+                break
             s = s.intersection({a if not a.startswith('_') else None for a in dir(resp)})
 
-        s.remove(None)
+        if None in s:
+            s.remove(None)
         return s
 
-    def __str__(self):
-        """Print out human-readable summary of records retrieved"""
-        return str(self.build_table())
-
-    def __repr__(self):
-        """Print out human-readable summary of records retrieved"""
-        return repr(self.build_table())
-
-    def _repr_html_(self):
-        return self.build_table()._repr_html_()
-
-
-class DownloadFailed(Exception):
-    pass
-
-
-class MissingInformation(Exception):
-    pass
-
-
-class UnknownMethod(Exception):
-    pass
-
-
-class MultipleChoices(Exception):
-    pass
-
-
-class UnknownVersion(Exception):
-    pass
-
-
-class UnknownStatus(Exception):
-    pass
-
 
 class VSOClient(BaseClient):
     """
-    VSO Client
+    Allows queries and downloads from the Virtual Solar Observatory (VSO).
 
     Parameters
     ----------
@@ -336,15 +358,14 @@ class VSOClient(BaseClient):
         2010-01-01T01:00.
 
         >>> from datetime import datetime
-        >>> from sunpy.net import vso
+        >>> from sunpy.net import vso, attrs as a
         >>> client = vso.VSOClient()  # doctest: +REMOTE_DATA
         >>> client.search(
-        ...    vso.attrs.Time(datetime(2010, 1, 1), datetime(2010, 1, 1, 1)),
-        ...    vso.attrs.Instrument('eit') | vso.attrs.Instrument('aia'))   # doctest:  +REMOTE_DATA
-        <QTable length=5>
+        ...    a.Time(datetime(2010, 1, 1), datetime(2010, 1, 1, 1)),
+        ...    a.Instrument.eit | a.Instrument.aia)   # doctest:  +REMOTE_DATA
+        <sunpy.net.vso.vso.QueryResponse object at ...>
            Start Time [1]       End Time [1]    Source ...   Type   Wavelength [2]
                                                        ...             Angstrom
-               str19               str19         str4  ...   str8      float64
         ------------------- ------------------- ------ ... -------- --------------
         2010-01-01 00:00:08 2010-01-01 00:00:20   SOHO ... FULLDISK 195.0 .. 195.0
         2010-01-01 00:12:08 2010-01-01 00:12:20   SOHO ... FULLDISK 195.0 .. 195.0
@@ -364,10 +385,14 @@ class VSOClient(BaseClient):
         responses = []
         for block in walker.create(query, self.api):
             try:
+                query_response = self.api.service.Query(
+                    QueryRequest(block=block)
+                )
+                for resp in query_response:
+                    if resp["error"]:
+                        warnings.warn(resp["error"], SunpyUserWarning)
                 responses.append(
-                    VSOQueryResponse(self.api.service.Query(
-                        QueryRequest(block=block)
-                    ))
+                    VSOQueryResponse(query_response)
                 )
             except Exception as ex:
                 response = QueryResponse.create(self.merge(responses))
@@ -410,180 +435,56 @@ class VSOClient(BaseClient):
 
     @staticmethod
     def mk_filename(pattern, queryresponse, resp, url):
+        """
+        Generate the best possible (or least-worse) filename for a VSO download.
+
+        * Use the ``content-disposition`` header.
+        * Use `fileid` to generate a file name if content-disposition fails
+        * If everything else fails use the last segment of the URL and hope.
+        """
         name = None
-        url_filename = url.split('/')[-1]
         if resp:
-            name = resp.headers.get("Content-Disposition", url_filename)
-            if name:
-                name = get_content_disposition(name)
-        if not name:
+            cdheader = resp.headers.get("Content-Disposition", None)
+            if cdheader:
+                value, params = cgi.parse_header(cdheader)
+                name = params.get('filename', "")
+                # Work around https://github.com/sunpy/sunpy/issues/3372
+                if name.count('"') >= 2:
+                    name = name.split('"')[1]
+
+        if name is None:
+            # Advice from the VSO is to fallback to providerid + fileid
+            # As it's possible multiple providers give the same fileid.
+            # However, I haven't implemented this yet as it would be a breaking
+            # change to the filenames we expect.
+
+            # I don't know if we still need this bytes check in Python 3 only
+            # land, but I don't dare remove it.
             if isinstance(queryresponse.fileid, bytes):
-                name = queryresponse.fileid.decode("ascii", "ignore")
+                fileid = queryresponse.fileid.decode("ascii", "ignore")
             else:
-                name = queryresponse.fileid
+                fileid = queryresponse.fileid
 
-        fs_encoding = sys.getfilesystemencoding()
-        if fs_encoding is None:
-            fs_encoding = "ascii"
+            # Some providers make fileid a path
+            # Some also don't specify a file extension, but not a lot we can do
+            # about that.
+            name = fileid.split("/")[-1]
 
+        # If somehow we have got this far with an empty string, fallback to url segment
+        if not name:
+            name = url.split('/')[-1]
+
+        # Remove any not-filename appropriate characters
         name = slugify(name)
 
+        # If absolutely everything else fails make a filename based on download time
         if not name:
-            name = "file"
+            name = f"vso_file_{datetime.datetime.now().strftime('%Y%m%d%H%M%S%f')}"
 
         fname = pattern.format(file=name, **serialize_object(queryresponse))
 
         return fname
 
-    @deprecated("1.0", alternative="sunpy.net.Fido")
-    def query_legacy(self, tstart=None, tend=None, **kwargs):
-        """
-        Query data from the VSO mocking the IDL API as close as possible.
-        Either tstart and tend or date_start and date_end or date have
-        to be supplied.
-
-        Parameters
-        ----------
-        tstart : datetime.datetime
-            Start of the time-range in which records are searched.
-        tend : datetime.datetime
-            Start of the time-range in which records are searched.
-        date : str
-            (start date) - (end date)
-        start_date : datetime
-            the start date
-        end_date : datetime
-            the end date
-        wave : str
-            (min) - (max) (unit)
-        min_wave : str
-            minimum spectral range
-        max_wave : str
-            maximum spectral range
-        unit_wave : str
-            spectral range units (Angstrom, GHz, keV)
-        extent : str
-            VSO 'extent type' ... (FULLDISK, CORONA, LIMB, etc)
-        physobj : str
-            VSO 'physical observable'
-        provider : str
-            VSO ID for the data provider (SDAC, NSO, SHA, MSU, etc)
-        source : str
-            spacecraft or observatory (SOHO, YOHKOH, BBSO, etc)
-            synonyms : spacecraft, observatory
-        instrument : str
-            instrument ID (EIT, SXI-0, SXT, etc)
-            synonyms : telescope, inst
-        detector : str
-            detector ID (C3, EUVI, COR2, etc.)
-        layout : str
-            layout of the data (image, spectrum, time_series, etc.)
-        level : str
-            level of the data product (numeric range, see below)
-        pixels : str
-            number of pixels (numeric range, see below)
-        resolution : str
-            effective resolution (1 = full, 0.5 = 2x2 binned, etc)
-            numeric range, see below.
-        pscale : str
-            pixel scale, in arcseconds (numeric range, see below)
-        near_time : datetime
-            return record closest to the time.  See below.
-        sample : int
-            attempt to return only one record per SAMPLE seconds.  See below.
-
-        Numeric Ranges:
-
-            - May be entered as a string or any numeric type for equality matching
-            - May be a string of the format '(min) - (max)' for range matching
-            - May be a string of the form '(operator) (number)' where operator
-              is one of: lt gt le ge < > <= >=
-
-
-        Examples
-        --------
-        Query all data from eit between 2010-01-01T00:00 and
-        2010-01-01T01:00.
-
-        >>> from datetime import datetime
-        >>> from sunpy.net import vso
-        >>> client = vso.VSOClient()  # doctest: +SKIP
-        >>> qr = client.query_legacy(datetime(2010, 1, 1),
-        ...                          datetime(2010, 1, 1, 1),
-        ...                          instrument='eit')  # doctest: +SKIP
-
-        Returns
-        -------
-        out : :py:class:`QueryResult` (enhanced list)
-            Matched items. Return value is of same type as the one of
-            :py:class:`VSOClient.search`.
-        """
-        def sdk(key): return partial(lambda key, value: {key: value}, key)
-        ALIASES = {
-            'wave_min': sdk('wave_wavemin'),
-            'wave_max': sdk('wave_wavemax'),
-            'wave_type': sdk('wave_wavetype'),
-            'wave_unit': sdk('wave_waveunit'),
-            'min_wave': sdk('wave_wavemin'),
-            'max_wave': sdk('wave_wavemax'),
-            'type_wave': sdk('wave_wavetype'),
-            'unit_wave': sdk('wave_waveunit'),
-            'wave': _parse_waverange,
-            'inst': sdk('instrument'),
-            'telescope': sdk('instrument'),
-            'spacecraft': sdk('source'),
-            'observatory': sdk('source'),
-            'start_date': sdk('time_start'),
-            'end_date': sdk('time_end'),
-            'start': sdk('time_start'),
-            'end': sdk('time_end'),
-            'near_time': sdk('time_near'),
-            'date': _parse_date,
-            'layout': sdk('datatype'),
-        }
-        if tstart is not None:
-            kwargs.update({'time_start': tstart})
-        if tend is not None:
-            kwargs.update({'time_end': tend})
-
-        QueryRequest = self.api.get_type('VSO:QueryRequest')
-        VSOQueryResponse = self.api.get_type('VSO:QueryResponse')
-        block = self.api.get_type('VSO:QueryRequestBlock')()
-
-        for key, value in kwargs.items():
-            for k, v in ALIASES.get(key, sdk(key))(value).items():
-                if k.startswith('time'):
-                    v = parse_time(v).strftime(TIMEFORMAT)
-                attr = k.split('_')
-                lst = attr[-1]
-                rest = attr[:-1]
-
-                for elem in rest:
-                    try:
-                        if block[elem] is None:
-                            block[elem] = {}
-                        block = block[elem]
-                    except KeyError:
-                        raise ValueError(
-                            f"Unexpected argument {key!s}.")
-                if lst in block and block[lst]:
-                    raise ValueError(
-                        f"Got multiple values for {k!s}.")
-                block[lst] = v
-
-        return QueryResponse.create(VSOQueryResponse(
-            self.api.service.Query(QueryRequest(block=block))))
-
-    @deprecated("1.0")
-    def latest(self):
-        """ Return newest record (limited to last week). """
-        from datetime import datetime, timedelta
-        return self.query_legacy(
-            datetime.utcnow() - timedelta(7),
-            datetime.utcnow(),
-            time_near=datetime.utcnow()
-        )
-
     def fetch(self, query_response, path=None, methods=None, site=None,
               progress=True, overwrite=False, downloader=None, wait=True):
         """
@@ -701,7 +602,6 @@ class VSOClient(BaseClient):
                 item = _Str(maps[record_item.fileid]['path'])
             except KeyError:
                 continue
-            # pylint: disable=W0201
             item.meta = record_item
             ret.append(item)
         return ret
@@ -713,7 +613,7 @@ class VSOClient(BaseClient):
 
         return self.create_getdatarequest(
             {k: [x.fileid for x in v]
-                 for k, v in self.by_provider(response).items()},
+             for k, v in self.by_provider(response).items()},
             methods, info
         )
 
@@ -757,7 +657,6 @@ class VSOClient(BaseClient):
 
         return self.make('VSOGetDataRequest', request=request)
 
-    # pylint: disable=R0913,R0912
     def download_all(self, response, methods, downloader, path, qr, info=None):
         results = Results()
         GET_VERSION = [
@@ -776,7 +675,6 @@ class VSOClient(BaseClient):
 
             # If from_ and to are uninitialized, the else block of the loop
             # continues the outer loop and thus this code is never reached.
-            # pylint: disable=W0631
             code = (
                 dresponse.status[from_:to]
                 if getattr(dresponse, 'status', None) else '200'
@@ -862,12 +760,10 @@ class VSOClient(BaseClient):
         Returns a dictionary of fileids
         corresponding to records in the response.
         """
-
         return {
             record.fileid: record for record in response
         }
 
-    # pylint: disable=W0613
     def multiple_choices(self, choices, response):
         """ Override to pick between multiple download choices. """
         for elem in self.method_order:
@@ -875,16 +771,97 @@ class VSOClient(BaseClient):
                 return [elem]
         raise NoData
 
-    # pylint: disable=W0613
     def missing_information(self, info, field):
         """ Override to provide missing information. """
         raise NoData
 
-    # pylint: disable=W0613
     def unknown_method(self, response):
         """ Override to pick a new method if the current one is unknown. """
         raise NoData
 
     @classmethod
     def _can_handle_query(cls, *query):
-        return all([x.__class__.__name__ in attrs.__all__ for x in query])
+        required = {core_attrs.Time}
+        # Get all classes in core_attrs and attrs
+        optional = {value for (name, value) in inspect.getmembers(core_attrs) if
+                    name in core_attrs.__all__}
+        optional.update(value for (name, value) in inspect.getmembers(attrs) if
+                        name in attrs.__all__)
+        return cls.check_attr_types_in_query(query, required, optional)
+
+    @classmethod
+    def _attrs_module(cls):
+        return 'vso', 'sunpy.net.vso.attrs'
+
+    def __del__(self):
+        """
+        Attempt to close the connection, but if it fails, continue.
+        """
+        try:
+            self.api.transport.session.close()
+        except Exception as e:
+            log.debug(f"Failed to close VSO API connection with: {e}")
+
+    @classmethod
+    def register_values(cls):
+        # We always use the local file for now.
+        return cls.load_vso_values()
+
+    @staticmethod
+    def load_vso_values():
+        """
+        We take this list and register all the keywords as corresponding Attrs.
+
+        Returns
+        -------
+        dict
+            The constructed Attrs dictionary ready to be passed into Attr registry.
+        """
+        from sunpy.net import attrs as a
+
+        here = os.path.dirname(os.path.realpath(__file__))
+        with open(os.path.join(here, 'data', 'attrs.json'), 'r') as attrs_file:
+            keyword_info = json.load(attrs_file)
+
+        # Now to traverse the saved dict and give them attr keys.
+        attrs = {}
+        for key, value in keyword_info.items():
+            attr = getattr(a, key.capitalize(), None)
+            if attr is None:
+                attr = getattr(a.vso, key.capitalize())
+            attrs[attr] = value
+        return attrs
+
+    @staticmethod
+    def create_parse_vso_values():
+        """
+        Makes a network call to the VSO API that returns what keywords they support.
+        We take this list and register all the keywords as corresponding Attrs.
+        """
+        here = os.path.dirname(os.path.realpath(__file__))
+
+        # Keywords we are after
+        keywords = ["+detector", "+instrument", "+source", "+provider", "+physobs", "+level"]
+        # Construct and format the request
+        keyword_info = {}
+        url = "https://vso1.nascom.nasa.gov/cgi-bin/registry_json.cgi"
+        headers = {"Content-Type": "application/x-www-form-urlencoded"}
+        for keyword in keywords:
+            data = urlencode({'fields': f"['{keyword}']".replace("'", '"')}).encode('ascii')
+            req = Request(url=url, data=data, headers=headers)
+            response = urlopen(req)
+            keyword_info[keyword.replace("+", "")] = json.loads(response.read())
+
+        # Now to traverse the return and create attrs out of them.
+        attrs = {}
+        for key, value in keyword_info.items():
+            attrs[key] = []
+            for item in value:
+                if item:
+                    if key == "level":
+                        attrs[key].append((str(item[key]), str(item[key])))
+                    else:
+                        attrs[key].append((str(item[key]), str(item[key+"_long"])))
+
+        with open(os.path.join(here, 'data', 'attrs.json'), 'w') as attrs_file:
+            json.dump(attrs, attrs_file)
