@@ -1,25 +1,28 @@
 import os
-import pytest
 
 import numpy as np
+import pytest
+
 import astropy.units as u
-from astropy.coordinates import SkyCoord
-from astropy.coordinates import Longitude
+from astropy.coordinates import Longitude, SkyCoord
 from astropy.tests.helper import assert_quantity_allclose
 from astropy.time import TimeDelta
 
+import sunpy.data.test
+import sunpy.map
 from sunpy.coordinates import frames
 from sunpy.coordinates.ephemeris import get_earth
 from sunpy.map.maputils import map_edges
-from sunpy.physics.differential_rotation import (diff_rot, solar_rotate_coordinate,
-                                                 differential_rotate,
-                                                 _get_new_observer, _rotate_submap_edge,
-                                                 _get_extreme_position, _get_bounding_coordinates,
-                                                 _warp_sun_coordinates)
-import sunpy.data.test
-import sunpy.map
-
-# pylint: disable=C0103,R0904,W0201,W0212,W0232,E1103
+from sunpy.physics.differential_rotation import (
+    _get_bounding_coordinates,
+    _get_extreme_position,
+    _get_new_observer,
+    _rotate_submap_edge,
+    _warp_sun_coordinates,
+    diff_rot,
+    differential_rotate,
+    solar_rotate_coordinate,
+)
 
 # Please note the numbers in these tests are not checked for physical
 # accuracy, only that they are the values the function was outputting upon
@@ -49,6 +52,7 @@ import sunpy.map
 
 testpath = sunpy.data.test.rootdir
 
+
 @pytest.fixture
 def aia171_test_map():
     return sunpy.map.Map(os.path.join(testpath, 'aia_171_level1.fits'))
@@ -56,17 +60,17 @@ def aia171_test_map():
 
 @pytest.fixture
 def all_off_disk_map(aia171_test_map):
-    return aia171_test_map.submap((1, 1)*u.pix, (11, 12)*u.pix)
+    return aia171_test_map.submap((1, 1)*u.pix, top_right=(11, 12)*u.pix)
 
 
 @pytest.fixture
 def all_on_disk_map(aia171_test_map):
-    return aia171_test_map.submap((30, 60)*u.pix, (50, 85)*u.pix)
+    return aia171_test_map.submap((30, 60)*u.pix, top_right=(50, 85)*u.pix)
 
 
 @pytest.fixture
 def straddles_limb_map(aia171_test_map):
-    return aia171_test_map.submap((64, 80)*u.pix, (120, 127)*u.pix)
+    return aia171_test_map.submap((64, 80)*u.pix, top_right=(120, 127)*u.pix)
 
 
 @pytest.fixture
@@ -79,9 +83,9 @@ def aia171_test_map_with_mask(aia171_test_map):
 
 @pytest.fixture
 def aia171_test_submap(aia171_test_map):
-    bl = SkyCoord(-512 * u.arcsec,  100 * u.arcsec, frame=aia171_test_map.coordinate_frame)
+    bl = SkyCoord(-512 * u.arcsec, 100 * u.arcsec, frame=aia171_test_map.coordinate_frame)
     ur = SkyCoord(-100 * u.arcsec, 400 * u.arcsec, frame=aia171_test_map.coordinate_frame)
-    return aia171_test_map.submap(bl, ur)
+    return aia171_test_map.submap(bl, top_right=ur)
 
 
 @pytest.fixture
@@ -96,7 +100,7 @@ def test_single(seconds_per_day):
 
 def test_array(seconds_per_day):
     rot = diff_rot(10 * seconds_per_day, np.linspace(-70, 70, 2) * u.deg)
-    assert_quantity_allclose(rot, Longitude(np.array([110.2725,  110.2725]) * u.deg), rtol=1e-3)
+    assert_quantity_allclose(rot, Longitude(np.array([110.2725, 110.2725]) * u.deg), rtol=1e-3)
 
 
 def test_synodic(seconds_per_day):
@@ -133,7 +137,8 @@ def test_solar_rotate_coordinate():
     # Testing along the Sun-Earth line, observer is on the Earth
     obs_time = '2010-09-10 12:34:56'
     observer = get_earth(obs_time)
-    c = SkyCoord(-570*u.arcsec, 120*u.arcsec, obstime=obs_time, observer=observer, frame=frames.Helioprojective)
+    c = SkyCoord(-570*u.arcsec, 120*u.arcsec, obstime=obs_time,
+                 observer=observer, frame=frames.Helioprojective)
     new_time = '2010-09-11 12:34:56'
     new_observer = get_earth(new_time)
 
@@ -147,13 +152,15 @@ def test_solar_rotate_coordinate():
 
     # Test that the code properly filters the time keyword
     with pytest.raises(ValueError):
-        d = solar_rotate_coordinate(c, time='noon')
+        with pytest.warns(UserWarning, match="Using 'time' assumes an Earth-based observer"):
+            d = solar_rotate_coordinate(c, time='noon')
 
     # Test that the code gives the same output for multiple different inputs
     # that define the same observer location and time.
     for i, definition in enumerate((1 * u.day, TimeDelta(1*u.day), new_time, new_observer)):
         if i in (0, 1, 2):
-            d = solar_rotate_coordinate(c, time=definition)
+            with pytest.warns(UserWarning, match="Using 'time' assumes an Earth-based observer"):
+                d = solar_rotate_coordinate(c, time=definition)
         else:
             d = solar_rotate_coordinate(c, observer=definition)
 
@@ -195,11 +202,14 @@ def test_differential_rotate(aia171_test_map, all_off_disk_map, all_on_disk_map,
     # Test a map that straddles the limb - triggers sub full disk branches
     # Rotated map should have a smaller extent in the x - direction
     new_observer = get_earth(straddles_limb_map.date + 48*u.hr)
-    dmap = differential_rotate(straddles_limb_map, observer=new_observer)
+    # Ignore some invalid NaN comparisions within astropy
+    # (fixed in astropy 4.0.1 https://github.com/astropy/astropy/pull/9843)
+    with np.errstate(invalid='ignore'):
+        dmap = differential_rotate(straddles_limb_map, observer=new_observer)
     assert dmap.data.shape[1] < straddles_limb_map.data.shape[1]
 
     # The output map should have the positional properties of the observer
-    assert dmap.date == new_observer.obstime
+    assert dmap.date.isot == new_observer.obstime.isot
     assert dmap.heliographic_latitude == new_observer.lat
     assert dmap.heliographic_longitude == new_observer.lon
 
@@ -234,7 +244,8 @@ def test_get_new_observer(aia171_test_map):
 
     # When the time is set, a coordinate for Earth comes back out
     for time in (rotation_interval, new_time, time_delta):
-        new_observer = _get_new_observer(initial_obstime, None, time)
+        with pytest.warns(UserWarning, match="Using 'time' assumes an Earth-based observer"):
+            new_observer = _get_new_observer(initial_obstime, None, time)
         assert isinstance(new_observer, SkyCoord)
 
         np.testing.assert_almost_equal(new_observer.transform_to(frames.HeliographicStonyhurst).lon.to(u.deg).value,
@@ -282,18 +293,26 @@ def test_rotate_submap_edge(aia171_test_map, all_off_disk_map, all_on_disk_map,
     for this_edge in (1, 2):  # Bottom and left edges do move
         pixels = edges[this_edge]
         res = _rotate_submap_edge(straddles_limb_map, pixels, observer)
-        assert all(res.Tx != (straddles_limb_map.pixel_to_world(pixels[:, 0], pixels[:, 1])).Tx)
-        assert all(res.Ty != (straddles_limb_map.pixel_to_world(pixels[:, 0], pixels[:, 1])).Ty)
+        # Ignore some invalid NaN comparisions within astropy
+        # (fixed in astropy 4.0.1 https://github.com/astropy/astropy/pull/9843)
+        with np.errstate(invalid='ignore'):
+            assert all(res.Tx != (straddles_limb_map.pixel_to_world(pixels[:, 0], pixels[:, 1])).Tx)
+            assert all(res.Ty != (straddles_limb_map.pixel_to_world(pixels[:, 0], pixels[:, 1])).Ty)
 
 
 def test_get_extreme_position():
-    coords = SkyCoord([-1, 0, 1, np.nan]*u.arcsec, [-2, 0, 2, -np.nan]*u.arcsec, frame=frames.Helioprojective)
+    # Ignore some invalid NaN comparisions within astropy
+    # (fixed in astropy 4.0.1 https://github.com/astropy/astropy/pull/9843)
+    with np.errstate(invalid='ignore'):
+        coords = SkyCoord([-1, 0, 1, np.nan]*u.arcsec, [-2, 0, 2, -np.nan]
+                          * u.arcsec, frame=frames.Helioprojective)
 
-    assert _get_extreme_position(coords, 'Tx', operator=np.nanmin) == -1
-    assert _get_extreme_position(coords, 'Ty', operator=np.nanmin) == -2
+    with pytest.warns(RuntimeWarning, match='All-NaN axis encountered'):
+        assert _get_extreme_position(coords, 'Tx', operator=np.nanmin) == -1
+        assert _get_extreme_position(coords, 'Ty', operator=np.nanmin) == -2
 
-    assert _get_extreme_position(coords, 'Tx', operator=np.nanmax) == 1
-    assert _get_extreme_position(coords, 'Ty', operator=np.nanmax) == 2
+        assert _get_extreme_position(coords, 'Tx', operator=np.nanmax) == 1
+        assert _get_extreme_position(coords, 'Ty', operator=np.nanmax) == 2
 
     with pytest.raises(ValueError):
         _get_extreme_position(coords, 'lon', operator=np.nanmax)
@@ -334,5 +353,6 @@ def test_warp_sun_coordinates(all_on_disk_map):
 
 @pytest.mark.array_compare
 def test_differential_rotation(aia171_test_map):
-    rot_map = differential_rotate(aia171_test_map, time=2*u.day)
+    with pytest.warns(UserWarning, match="Using 'time' assumes an Earth-based observer"):
+        rot_map = differential_rotate(aia171_test_map, time=2*u.day)
     return rot_map.data
