@@ -1,15 +1,16 @@
 import os
-import urllib
 import platform
 import warnings
-import pkg_resources
+from pathlib import Path
 from functools import wraps
 
+import matplotlib as mpl
 import matplotlib.pyplot as plt
+import numpy.distutils.system_info as sysinfo
+import pkg_resources
 import pytest
-from matplotlib.testing import compare
 
-from sunpy.tests import hash
+import astropy
 
 __all__ = ['skip_windows', 'skip_glymur', 'skip_ana', 'skip_32bit',
            'warnings_as_errors', 'asdf_entry_points']
@@ -22,19 +23,18 @@ except ImportError:
     SKIP_GLYMUR = True
 else:
     # See if we have a C backend
-    if any((glymur.lib.openjp2.OPENJP2, glymur.lib.openjpeg.OPENJPEG)):
+    if glymur.lib.openjp2.OPENJP2:
         SKIP_GLYMUR = False
     else:
         SKIP_GLYMUR = True
 
 try:
-    from sunpy.io import _pyana  # noqa
+    from sunpy.io import _pyana  # NOQA
 except ImportError:
     SKIP_ANA = True
 else:
     SKIP_ANA = False
 
-import numpy.distutils.system_info as sysinfo
 if sysinfo.platform_bits == 64:
     SKIP_32 = False
 else:
@@ -61,6 +61,16 @@ def warnings_as_errors(request):
 new_hash_library = {}
 
 
+def get_hash_library_name():
+    """
+    Generate the hash library name for this env.
+    """
+    ft2_version = f"{mpl.ft2font.__freetype_version__.replace('.', '')}"
+    mpl_version = "dev" if "+" in mpl.__version__ else mpl.__version__.replace('.', '')
+    astropy_version = "dev" if "dev" in astropy.__version__ else astropy.__version__.replace('.', '')
+    return f"figure_hashes_mpl_{mpl_version}_ft_{ft2_version}_astropy_{astropy_version}.json"
+
+
 def figure_test(test_function):
     """
     A decorator for a test that verifies the hash of the current figure or the
@@ -76,43 +86,21 @@ def figure_test(test_function):
     def test_simple_plot():
         plt.plot([0,1])
     """
-    @pytest.mark.figure
+    hash_library_name = get_hash_library_name()
+    hash_library_file = Path(__file__).parent / hash_library_name
+
+    @pytest.mark.remote_data
+    @pytest.mark.mpl_image_compare(hash_library=hash_library_file,
+                                   savefig_kwargs={'metadata': {'Software': None}},
+                                   style='default')
     @wraps(test_function)
-    def wrapper(*args, **kwargs):
-        if not os.path.exists(hash.HASH_LIBRARY_FILE):
-            pytest.xfail(f'Could not find a figure hash library at {hash.HASH_LIBRARY_FILE}')
-        # figure_base_dir is a pytest fixture defined on use.
-        if figure_base_dir is None:
-            pytest.xfail("No directory to save figures to found")
+    def test_wrapper(*args, **kwargs):
+        ret = test_function(*args, **kwargs)
+        if ret is None:
+            ret = plt.gcf()
+        return ret
 
-        name = "{}.{}".format(test_function.__module__,
-                              test_function.__name__)
-        # Run the test function and get the figure
-        plt.figure()
-        fig = test_function(*args, **kwargs)
-        if fig is None:
-            fig = plt.gcf()
-
-        # Save the image that was generated
-        figure_base_dir.mkdir(exist_ok=True)
-        result_image_loc = figure_base_dir / f'{name}.png'
-        plt.savefig(str(result_image_loc))
-        plt.close()
-
-        # Create hash
-        imgdata = open(result_image_loc, "rb")
-        figure_hash = hash._hash_file(imgdata)
-        imgdata.close()
-
-        new_hash_library[name] = figure_hash
-        if name not in hash.hash_library:
-            pytest.fail(f"Hash not present: {name}")
-
-        if hash.hash_library[name] != figure_hash:
-            raise RuntimeError('Figure hash does not match expected hash.\n'
-                               'New image generated and placed at {}'.format(result_image_loc))
-
-    return wrapper
+    return test_wrapper
 
 
 # Skip coverage on this because we test it every time the CI runs --coverage!
@@ -154,65 +142,18 @@ def _patch_coverage(testdir, sourcedir):  # pragma: no cover
     cov.save()
 
 
-html_intro = '''
-<!DOCTYPE html>
-<html>
-<head>
-<style>
-table, th, td {
-    border: 1px solid black;
-}
-</style>
-</head>
-<body>
+def no_vso(f):
+    """
+    Disable the VSO client from returning results via Fido during this test.
+    """
+    from sunpy.net import Fido
+    from sunpy.net.vso import VSOClient
 
-<h2>Image test comparison</h2>
+    @wraps(f)
+    def wrapper(*args, **kwargs):
+        Fido.registry[VSOClient] = lambda *args: False
+        res = f(*args, **kwargs)
+        Fido.registry[VSOClient] = VSOClient._can_handle_query
+        return res
 
-<table>
-  <tr>
-    <th>Test Name</th>
-    <th>Baseline image</th>
-    <th>Diff</th>
-    <th>New image</th>
-  </tr>
-'''
-
-
-def _generate_fig_html(fname):
-    generated_image = figure_base_dir / (fname + '.png')
-
-    # Download baseline image
-    baseline_url = 'https://raw.githubusercontent.com/sunpy/sunpy-figure-tests/master/figures/'
-    baseline_image_url = baseline_url + generated_image.name
-    baseline_image = figure_base_dir / (generated_image.stem + '_baseline' + generated_image.suffix)
-    baseline_image_exists = baseline_image.exists()
-    if not baseline_image_exists:
-        try:
-            urllib.request.urlretrieve(baseline_image_url, baseline_image)
-            baseline_image_exists = True
-        except urllib.error.HTTPError:
-            pass
-
-    # Create diff between baseline and generated image
-    diff_image = figure_base_dir / (generated_image.stem + '_diff' + generated_image.suffix)
-    if baseline_image_exists:
-        compare.save_diff_image(str(baseline_image), str(generated_image), str(diff_image))
-
-    html_block = ('<tr>'
-                  '<td>{}\n'.format(generated_image.stem) +
-                  f'<td><img src="{baseline_image.name}"></td>\n' +
-                  f'<td><img src="{diff_image.name}"></td>\n' +
-                  f'<td><img src="{generated_image.name}"></td>\n' +
-                  '</tr>\n\n')
-    return html_block
-
-
-def generate_figure_webpage(hash_library):
-    html_file = figure_base_dir / 'fig_comparison.html'
-    with open(html_file, 'w') as f:
-        f.write(html_intro)
-        for fname in hash_library:
-            f.write(_generate_fig_html(fname))
-        f.write('</table>')
-        f.write('</body>')
-        f.write('</html>')
+    return wrapper
