@@ -3,16 +3,15 @@ This module FERMI GBM `~sunpy.timeseries.TimeSeries` source.
 """
 from collections import OrderedDict
 
-import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 
 import astropy.units as u
-from astropy.time import Time
+from astropy.time import TimeDelta
 
 import sunpy.io
-from sunpy.instr import fermi
+from sunpy.time import parse_time
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
 from sunpy.util.metadata import MetaDict
 from sunpy.visualization import peek_show
@@ -22,9 +21,9 @@ __all__ = ['GBMSummaryTimeSeries']
 
 class GBMSummaryTimeSeries(GenericTimeSeries):
     """
-    Fermi/GBM Summary Lightcurve TimeSeries.
+    Fermi/GBM Summary lightcurve TimeSeries.
 
-    The Gamma-ray Burst Monitor (GBM) is an instrument aboard Fermi.
+    The Gamma-ray Burst Monitor (GBM) is an instrument on board Fermi.
     It is meant to detect gamma-ray bursts but also detects solar flares.
     It consists of 12 Sodium Iodide (NaI) scintillation detectors and 2 Bismuth Germanate (BGO) scintillation detectors.
     The NaI detectors cover from a few keV to about 1 MeV and provide burst triggers and locations.
@@ -61,7 +60,7 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
     _source = 'gbmsummary'
 
     @peek_show
-    def peek(self):
+    def peek(self, **kwargs):
         """
         Plots the GBM lightcurve TimeSeries. An example can be seen below:
 
@@ -71,21 +70,26 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
             import sunpy.data.sample
             gbm = sunpy.timeseries.TimeSeries(sunpy.data.sample.GBM_TIMESERIES, source='GBMSummary')
             gbm.peek()
+
+        Parameters
+        ----------
+        **kwargs : `dict`
+            Additional plot keyword arguments that are handed to `axes.plot` functions
         """
         # Check we have a timeseries valid for plotting
-        self._validate_data_for_ploting()
+        self._validate_data_for_plotting()
 
         figure = plt.figure()
         axes = plt.gca()
-        data_lab = self.data.columns.values
+        data_lab = self.to_dataframe().columns.values
 
         for d in data_lab:
-            axes.plot(self.data.index, self.data[d], label=d)
+            axes.plot(self.to_dataframe().index, self.to_dataframe()[d], label=d, **kwargs)
 
         axes.set_yscale("log")
         axes.set_title('Fermi GBM Summary data ' + str(self.meta.get(
             'DETNAM').values()))
-        axes.set_xlabel('Start time: ' + self.data.index[0].strftime(
+        axes.set_xlabel('Start time: ' + self.to_dataframe().index[0].strftime(
             '%Y-%m-%d %H:%M:%S UT'))
         axes.set_ylabel('Counts/s/keV')
         axes.legend()
@@ -130,7 +134,8 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
         summary_counts = _bin_data_for_summary(energy_bins, count_data)
 
         # get the time information in datetime format with the correct MET adjustment
-        gbm_times = Time([fermi.met_to_utc(t) for t in count_data['time']])
+        met_ref_time = parse_time('2001-01-01 00:00')  # Mission elapsed time
+        gbm_times = met_ref_time + TimeDelta(count_data['time'], format='sec')
         gbm_times.precision = 9
         gbm_times = gbm_times.isot.astype('datetime64')
 
