@@ -5,7 +5,6 @@ import datetime
 from collections import OrderedDict
 
 import matplotlib.dates
-import matplotlib as mpl
 import matplotlib.pyplot as plt
 from pandas import DataFrame
 
@@ -22,7 +21,7 @@ __all__ = ['RHESSISummaryTimeSeries']
 
 class RHESSISummaryTimeSeries(GenericTimeSeries):
     """
-    RHESSI X-ray Summary Lightcurve TimeSeries.
+    RHESSI X-ray Summary lightcurve TimeSeries.
 
     The RHESSI mission consists of a single spin-stabilized spacecraft in a low-altitude orbit
     inclined 38 degrees to the Earth's equator.
@@ -62,7 +61,7 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
     _source = 'rhessi'
 
     @peek_show
-    def peek(self, title="RHESSI Observing Summary Count Rate"):
+    def peek(self, title="RHESSI Observing Summary Count Rate", **kwargs):
         """
         Plots RHESSI Count Rate light curve. An example is shown below:
 
@@ -77,20 +76,23 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
         ----------
         title : `str`
             The title of the plot.
+        **kwargs : `dict`
+            Additional plot keyword arguments that are handed to `axes.plot` functions
         """
         # Check we have a timeseries valid for plotting
-        self._validate_data_for_ploting()
+        self._validate_data_for_plotting()
 
         figure = plt.figure()
         axes = plt.gca()
 
         lc_linecolors = rhessi.hsi_linecolors()
 
-        for lc_color, (item, frame) in zip(lc_linecolors, self.data.items()):
-            axes.plot_date(self.data.index, frame.values, '-', label=item, lw=2, color=lc_color)
+        for lc_color, (item, frame) in zip(lc_linecolors, self.to_dataframe().items()):
+            axes.plot_date(self.to_dataframe().index, frame.values, '-',
+                           label=item, lw=2, color=lc_color, **kwargs)
 
         axes.set_yscale("log")
-        axes.set_xlabel(datetime.datetime.isoformat(self.data.index[0])[0:10])
+        axes.set_xlabel(datetime.datetime.isoformat(self.to_dataframe().index[0])[0:10])
 
         axes.set_title(title)
         axes.set_ylabel('Count Rate s$^{-1}$ detector$^{-1}$')
