@@ -3,6 +3,8 @@ This module provides multimethod implementation in pure Python.
 """
 from warnings import warn
 
+from sunpy.util.exceptions import SunpyDeprecationWarning
+
 __all__ = ['TypeWarning', 'MultiMethod']
 
 SILENT = 0
@@ -28,7 +30,9 @@ class MultiMethod:
     get : `function`
         The function which receives args and kwargs and returns a tuple of values to consider for dispatch.
     """
+
     def __init__(self, get):
+        warn("MultiMethod is deprecated and will be removed in sunpy 2.1", SunpyDeprecationWarning)
         self.get = get
 
         self.methods = []
@@ -65,7 +69,7 @@ class MultiMethod:
             raise TypeError
         elif overriden and override == WARN:
             warn('Definition ({}) overrides prior definition ({}).'.format(_fmt_t(types),
-                                                                             _fmt_t(signature)),
+                                                                           _fmt_t(signature)),
                  TypeWarning, stacklevel=3)
 
         self.methods.append((types, fun))
