@@ -1,5 +1,5 @@
 import datetime
-from unittest.mock import patch, Mock
+from unittest.mock import Mock, patch
 
 import pytest
 
@@ -160,10 +160,7 @@ def testURL_patternMillisecondsZeroPadded():
     assert s.now == 'fd_20190419_000000_004.fts'
 
 
-@pytest.mark.xfail
 def testFilesRange_sameDirectory_local():
-    # Fails due to an IsADirectoryError, wrapped in a URLError, after `requests`
-    # tries to open a directory as a binary file.
     s = Scraper('/'.join(['file:/', rootdir,
                           'EIT', 'efz%Y%m%d.%H%M%S_s.fits']))
     startdate = parse_time((2004, 3, 1, 4, 0))
@@ -174,7 +171,6 @@ def testFilesRange_sameDirectory_local():
     assert len(s.filelist(TimeRange(startdate, enddate))) == 0
 
 
-@pytest.mark.xfail
 @pytest.mark.remote_data
 def testFilesRange_sameDirectory_remote():
     pattern = ('http://solarmonitor.org/data/%Y/%m/%d/'
@@ -191,7 +187,6 @@ def testFilesRange_sameDirectory_remote():
     assert len(s.filelist(timerange)) == 0
 
 
-@pytest.mark.xfail
 @pytest.mark.remote_data
 def testFilesRange_sameDirectory_months_remote():
     pattern = ('http://www.srl.caltech.edu/{spacecraft}/DATA/{instrument}/'
@@ -208,7 +203,10 @@ def test_ftp():
     pattern = 'ftp://solar-pub.nao.ac.jp/pub/nsro/norh/data/tcx/%Y/%m/tca%y%m%d'
     s = Scraper(pattern)
     timerange = TimeRange('2016/5/18 15:28:00', '2016/5/20 16:30:50')
-    assert len(s.filelist(timerange)) == 2
+    urls = s.filelist(timerange)
+    assert urls[0] == ('ftp://solar-pub.nao.ac.jp'
+                       '/pub/nsro/norh/data/tcx/2016/05/tca160519')
+    assert len(urls) == 2
 
 
 @pytest.mark.remote_data
@@ -219,3 +217,35 @@ def test_filelist_url_missing_directory():
     s = Scraper(pattern)
     timerange = TimeRange('1960/01/01 00:00:00', '1960/01/02 00:00:00')
     assert len(s.filelist(timerange)) == 0
+
+
+@pytest.mark.remote_data
+def test_filelist_relative_hrefs():
+    # the url opened by the scraper from below pattern contains some links which don't have hrefs
+    pattern = 'http://www.bbso.njit.edu/pub/archive/%Y/%m/%d/bbso_halph_fr_%Y%m%d_%H%M%S.fts'
+    s = Scraper(pattern)
+    timerange = TimeRange('2016/5/18 15:28:00', '2016/5/18 16:30:00')
+    assert s.domain == 'http://www.bbso.njit.edu/'
+    # hrefs are relative to domain here, not to the directory they are present in
+    # this checks that `scraper.filelist` returns fileurls relative to the domain
+    fileurls = s.filelist(timerange)
+    assert fileurls[1] == s.domain + 'pub/archive/2016/05/18/bbso_halph_fr_20160518_160033.fts'
+
+
+@pytest.mark.parametrize('pattern, check_file', [
+    (r'MyFile_%Y_%M_%e\.(\D){2}\.fits', 'MyFile_2020_55_234.aa.fits'),
+    (r'(\d){5}_(\d){2}\.fts', '01122_25.fts'),
+    (r'_%Y%m%d__%ec(\d){5}_(\d){2}\s.fts', '_20201535__012c12345_33 .fts')])
+def test_regex(pattern, check_file):
+    s = Scraper(pattern, regex=True)
+    assert s._URL_followsPattern(check_file)
+
+
+@pytest.mark.remote_data
+def test_regex_data():
+    prefix = r'https://gong2.nso.edu/oQR/zqs/'
+    pattern = prefix + r'%Y%m/mrzqs%y%m%d/mrzqs%y%m%dt%H%Mc(\d){4}_(\d){3}\.fits.gz'
+    s = Scraper(pattern, regex=True)
+    timerange = TimeRange('2020-01-05', '2020-01-06T16:00:00')
+    assert s._URL_followsPattern(prefix + '202001/mrzqs200106/mrzqs200106t1514c2226_297.fits.gz')
+    assert len(s.filelist(timerange)) == 37
